# -*- fundamental -*-
#
# The long dictionary constants in this file cause emacs Python mode to
# hang for seconds or minutes every now and then, and thus editing in
# fundamental mode is much more convenient...

# Definitions for inflecting verbs using Wiktionary-compatible conjugation
# data.  Verb inflection may also use noun declensions in addition to these.
#
# See nounspecs.py for how the entries are formatted.
#
# Copyright (c) 2018 Tatu Ylonen.  See COPYING.

verb_conjs = {
    "fi-conj-sanoa": {
    	"nargs": 5,
        "pres-1sg": "134n",
        "pres-2sg": "134t",
        "pres-3sg": "1244",
        "pres-1pl": "134mme",
        "pres-2pl": "134tte",
        "pres-3pl": "124v5t",
        "pres-pass": "134t55n",
        "pres-1sg-neg": "134",
        "pres-2sg-neg": "134",
        "pres-3sg-neg": "134",
        "pres-1pl-neg": "134",
        "pres-2pl-neg": "134",
        "pres-3pl-neg": "134",
        "pres-pass-neg": "134t5",
        "past-1sg": "134in",
        "past-2sg": "134it",
        "past-3sg": "124i",
        "past-1pl": "134imme",
        "past-2pl": "134itte",
        "past-3pl": "124iv5t",
        "past-pass": "134ttiin",
        "past-1sg-neg": "124n5-Ut",
        "past-2sg-neg": "124n5-Ut",
        "past-3sg-neg": "124n5-Ut",
        "past-1pl-neg": "124neet",
        "past-2pl-neg": "124neet",
        "past-3pl-neg": "124neet",
        "past-pass-neg": "134tt5-U",
        "cond-1sg": "124isin",
        "cond-2sg": "124isit",
        "cond-3sg": "124isi",
        "cond-1pl": "124isimme",
        "cond-2pl": "124isitte",
        "cond-3pl": "124isiv5t",
        "cond-pass": "134tt5isiin",
        "cond-1sg-neg": "124isi",
        "cond-2sg-neg": "124isi",
        "cond-3sg-neg": "124isi",
        "cond-1pl-neg": "124isi",
        "cond-2pl-neg": "124isi",
        "cond-3pl-neg": "124isi",
        "cond-pass-neg": "134tt5isi",
        "impr-2sg": "134",
        "impr-3sg": "124k5-OOn",
        "impr-1pl": "124k55mme",
        "impr-2pl": "124k55",
        "impr-3pl": "124k5-OOt",
        "impr-pass": "134tt5kOOn",
        "impr-2sg-neg": "134",
        "impr-3sg-neg": "124k5-O",
        "impr-1pl-neg": "124k5-O",
        "impr-2pl-neg": "124k5-O",
        "impr-3pl-neg": "124k5-O",
        "impr-pass-neg": "134tt5kO",
        "potn-1sg": "124nen",
        "potn-2sg": "124net",
        "potn-3sg": "124nee",
        "potn-1pl": "124nemme",
        "potn-2pl": "124nette",
        "potn-3pl": "124nev5t",
        "potn-pass": "134tt5neen",
        "potn-1sg-neg": "124ne",
        "potn-2sg-neg": "124ne",
        "potn-3sg-neg": "124ne",
        "potn-1pl-neg": "124ne",
        "potn-2pl-neg": "124ne",
        "potn-3pl-neg": "124ne",
        "potn-pass-neg": "134tt5ne",
        "pres-part": "124v5",
        "pres-pass-part": "134tt5v5",
        "past-part": "124n5-Ut",
        "past-pass-part": "134tt5-U",
        "agnt-part": "124m5",
        "nega-part": "124m5tOn",
        "inf1": "1245",
        "inf1-long": "1245kse",  # +poss_suff
        "inf2-ine": "124ess5",
        "inf2-pass-ine": "134tt5ess5",
        "inf2-ins": "124en",
        "inf3-ine": "124m5ss5",
        "inf3-ela": "124m5st5",
        "inf3-ill": "124m55n",
        "inf3-ade": "124m5ll5",
        "inf3-abe": "124m5tt5",
        "inf3-ins": "124m5n",
        "inf3-pass-ins": "134tt5m5n",
        "inf4-nom": "124minen",
        "inf4-nom-poss": "124mise",
        "inf4-par": "124mist5",
        "inf5": "124m5isill5",  # +poss_suff
    },
    "fi-conj-muistaa": {
    	"nargs": 4,
        "pres-1sg": "134n",
        "pres-2sg": "134t",
        "pres-3sg": "1244",
        "pres-1pl": "134mme",
        "pres-2pl": "134tte",
        "pres-3pl": "124v4t",
        "pres-pass": "13et44n",
        "pres-1sg-neg": "134",
        "pres-2sg-neg": "134",
        "pres-3sg-neg": "134",
        "pres-1pl-neg": "134",
        "pres-2pl-neg": "134",
        "pres-3pl-neg": "134",
        "pres-pass-neg": "13et4",
        "past-1sg": "13in",
        "past-2sg": "13it",
        "past-3sg": "12i",
        "past-1pl": "13imme",
        "past-2pl": "13itte",
        "past-3pl": "12iv4t",
        "past-pass": "13ettiin",
        "past-1sg-neg": "124nUt",
        "past-2sg-neg": "124nUt",
        "past-3sg-neg": "124nUt",
        "past-1pl-neg": "124neet",
        "past-2pl-neg": "124neet",
        "past-3pl-neg": "124neet",
        "past-pass-neg": "13ett4-U",
        "cond-1sg": "124isin",
        "cond-2sg": "124isit",
        "cond-3sg": "124isi",
        "cond-1pl": "124isimme",
        "cond-2pl": "124isitte",
        "cond-3pl": "124isiv4t",
        "cond-pass": "13ett4isiin",
        "cond-1sg-neg": "124isi",
        "cond-2sg-neg": "124isi",
        "cond-3sg-neg": "124isi",
        "cond-1pl-neg": "124isi",
        "cond-2pl-neg": "124isi",
        "cond-3pl-neg": "124isi",
        "cond-pass-neg": "13ett4isi",
        "impr-2sg": "134",
        "impr-3sg": "124kOOn",
        "impr-1pl": "124k44mme",
        "impr-2pl": "124k44",
        "impr-3pl": "124kOOt",
        "impr-pass": "13ett4kOOn",
        "impr-2sg-neg": "134",
        "impr-3sg-neg": "124kO",
        "impr-1pl-neg": "124kO",
        "impr-2pl-neg": "124kO",
        "impr-3pl-neg": "124kO",
        "impr-pass-neg": "13ett4kO",
        "potn-1sg": "124nen",
        "potn-2sg": "124net",
        "potn-3sg": "124nee",
        "potn-1pl": "124nemme",
        "potn-2pl": "124nette",
        "potn-3pl": "124nev4t",
        "potn-pass": "13ett4neen",
        "potn-1sg-neg": "124ne",
        "potn-2sg-neg": "124ne",
        "potn-3sg-neg": "124ne",
        "potn-1pl-neg": "124ne",
        "potn-2pl-neg": "124ne",
        "potn-3pl-neg": "124ne",
        "potn-pass-neg": "13ett4ne",
        "pres-part": "124v4",
        "pres-pass-part": "13ett4v4",
        "past-part": "124nUt",
        "past-pass-part": "13ett4-U",
        "agnt-part": "124m4",
        "nega-part": "124m4tOn",
        "inf1": "1244",
        "inf1-long": "1244kse",  # +poss_suff
        "inf2-ine": "124ess4",
        "inf2-pass-ine": "13ett4ess4",
        "inf2-ins": "124en",
        "inf3-ine": "124m4ss4",
        "inf3-ela": "124m4st4",
        "inf3-ill": "124m44n",
        "inf3-ade": "124m4ll4",
        "inf3-abe": "124m4tt4",
        "inf3-ins": "124m4n",
        "inf3-pass-ins": "13ett4m4n",
        "inf4-nom": "124minen",
        "inf4-nom-poss": "124mise",
        "inf4-par": "124mist4",
        "inf5": "124m4isill4",  # +poss_suff
    },
    "fi-conj-huutaa": {
    	"nargs": 2,
        "pres-1sg": "1D2n",
        "pres-2sg": "1D2t",
        "pres-3sg": "1t22",
        "pres-1pl": "1D2mme",
        "pres-2pl": "1D2tte",
        "pres-3pl": "1t2v2t",
        "pres-pass": "1Det22n",
        "pres-1sg-neg": "1D2",
        "pres-2sg-neg": "1D2",
        "pres-3sg-neg": "1D2",
        "pres-1pl-neg": "1D2",
        "pres-2pl-neg": "1D2",
        "pres-3pl-neg": "1D2",
        "pres-pass-neg": "1Det2",
        "past-1sg": "1sin",
        "past-2sg": "1sit",
        "past-3sg": "1si",
        "past-1pl": "1simme",
        "past-2pl": "1sitte",
        "past-3pl": "1siv2t",
        "past-pass": "1Dettiin",
        "past-1sg-neg": "1t2nUt",
        "past-2sg-neg": "1t2nUt",
        "past-3sg-neg": "1t2nUt",
        "past-1pl-neg": "1t2neet",
        "past-2pl-neg": "1t2neet",
        "past-3pl-neg": "1t2neet",
        "past-pass-neg": "1Dett2-U",
        "cond-1sg": "1t2isin",
        "cond-2sg": "1t2isit",
        "cond-3sg": "1t2isi",
        "cond-1pl": "1t2isimme",
        "cond-2pl": "1t2isitte",
        "cond-3pl": "1t2isiv2t",
        "cond-pass": "1Dett2isiin",
        "cond-1sg-neg": "1t2isi",
        "cond-2sg-neg": "1t2isi",
        "cond-3sg-neg": "1t2isi",
        "cond-1pl-neg": "1t2isi",
        "cond-2pl-neg": "1t2isi",
        "cond-3pl-neg": "1t2isi",
        "cond-pass-neg": "1Dett2isi",
        "impr-2sg": "1D2",
        "impr-3sg": "1t2kOOn",
        "impr-1pl": "1t2k22mme",
        "impr-2pl": "1t2k22",
        "impr-3pl": "1t2kOOt",
        "impr-pass": "1Dett2kOOn",
        "impr-2sg-neg": "1D2",
        "impr-3sg-neg": "1t2kO",
        "impr-1pl-neg": "1t2kO",
        "impr-2pl-neg": "1t2kO",
        "impr-3pl-neg": "1t2kO",
        "impr-pass-neg": "1Dett2kO",
        "potn-1sg": "1t2nen",
        "potn-2sg": "1t2net",
        "potn-3sg": "1t2nee",
        "potn-1pl": "1t2nemme",
        "potn-2pl": "1t2nette",
        "potn-3pl": "1t2nev2t",
        "potn-pass": "1Dett2neen",
        "potn-1sg-neg": "1t2ne",
        "potn-2sg-neg": "1t2ne",
        "potn-3sg-neg": "1t2ne",
        "potn-1pl-neg": "1t2ne",
        "potn-2pl-neg": "1t2ne",
        "potn-3pl-neg": "1t2ne",
        "potn-pass-neg": "1Dett2ne",
        "pres-part": "1t2v2",
        "pres-pass-part": "1Dett2v2",
        "past-part": "1t2nUt",
        "past-pass-part": "1Dett2-U",
        "agnt-part": "1t2m2",
        "nega-part": "1t2m2tOn",
        "inf1": "1t22",
        "inf1-long": "1t22kse",  # +poss_suff
        "inf2-ine": "1t2ess2",
        "inf2-pass-ine": "1Dett2ess2",
        "inf2-ins": "1t2en",
        "inf3-ine": "1t2m2ss2",
        "inf3-ela": "1t2m2st2",
        "inf3-ill": "1t2m22n",
        "inf3-ade": "1t2m2ll2",
        "inf3-abe": "1t2m2tt2",
        "inf3-ins": "1t2m2n",
        "inf3-pass-ins": "1Dett2m2n",
        "inf4-nom": "1t2minen",
        "inf4-nom-poss": "1t2mise",
        "inf4-par": "1t2mist2",
        "inf5": "1t2m2isill2",  # +poss_suff
    },
    "fi-conj-soutaa": {
    	"nargs": 2,
        "pres-1sg": "1D2n",
        "pres-2sg": "1D2t",
        "pres-3sg": "1t22",
        "pres-1pl": "1D2mme",
        "pres-2pl": "1D2tte",
        "pres-3pl": "1t2v2t",
        "pres-pass": "1Det22n",
        "pres-1sg-neg": "1D2",
        "pres-2sg-neg": "1D2",
        "pres-3sg-neg": "1D2",
        "pres-1pl-neg": "1D2",
        "pres-2pl-neg": "1D2",
        "pres-3pl-neg": "1D2",
        "pres-pass-neg": "1Det2",
        "past-1sg": ["1Din", "1sin"],
        "past-2sg": ["1Dit", "1sit"],
        "past-3sg": ["1ti", "1si"],
        "past-1pl": ["1Dimme", "1simme"],
        "past-2pl": ["1Ditte", "1sitte"],
        "past-3pl": ["1tiv2t", "1siv2t"],
        "past-pass": "1Dettiin",
        "past-1sg-neg": "1t2nUt",
        "past-2sg-neg": "1t2nUt",
        "past-3sg-neg": "1t2nUt",
        "past-1pl-neg": "1t2neet",
        "past-2pl-neg": "1t2neet",
        "past-3pl-neg": "1t2neet",
        "past-pass-neg": "1Dett2-U",
        "cond-1sg": "1t2isin",
        "cond-2sg": "1t2isit",
        "cond-3sg": "1t2isi",
        "cond-1pl": "1t2isimme",
        "cond-2pl": "1t2isitte",
        "cond-3pl": "1t2isiv2t",
        "cond-pass": "1Dett2isiin",
        "cond-1sg-neg": "1t2isi",
        "cond-2sg-neg": "1t2isi",
        "cond-3sg-neg": "1t2isi",
        "cond-1pl-neg": "1t2isi",
        "cond-2pl-neg": "1t2isi",
        "cond-3pl-neg": "1t2isi",
        "cond-pass-neg": "1Dett2isi",
        "impr-2sg": "1D2",
        "impr-3sg": "1t2kOOn",
        "impr-1pl": "1t2k22mme",
        "impr-2pl": "1t2k22",
        "impr-3pl": "1t2kOOt",
        "impr-pass": "1Dett2kOOn",
        "impr-2sg-neg": "1D2",
        "impr-3sg-neg": "1t2kO",
        "impr-1pl-neg": "1t2kO",
        "impr-2pl-neg": "1t2kO",
        "impr-3pl-neg": "1t2kO",
        "impr-pass-neg": "1Dett2kO",
        "potn-1sg": "1t2nen",
        "potn-2sg": "1t2net",
        "potn-3sg": "1t2nee",
        "potn-1pl": "1t2nemme",
        "potn-2pl": "1t2nette",
        "potn-3pl": "1t2nev2t",
        "potn-pass": "1Dett2neen",
        "potn-1sg-neg": "1t2ne",
        "potn-2sg-neg": "1t2ne",
        "potn-3sg-neg": "1t2ne",
        "potn-1pl-neg": "1t2ne",
        "potn-2pl-neg": "1t2ne",
        "potn-3pl-neg": "1t2ne",
        "potn-pass-neg": "1Dett2ne",
        "pres-part": "1t2v2",
        "pres-pass-part": "1Dett2v2",
        "past-part": "1t2nUt",
        "past-pass-part": "1Dett2-U",
        "agnt-part": "1t2m2",
        "nega-part": "1t2m2tOn",
        "inf1": "1t22",
        "inf1-long": "1t22kse",  # +poss_suff
        "inf2-ine": "1t2ess2",
        "inf2-pass-ine": "1Dett2ess2",
        "inf2-ins": "1t2en",
        "inf3-ine": "1t2m2ss2",
        "inf3-ela": "1t2m2st2",
        "inf3-ill": "1t2m22n",
        "inf3-ade": "1t2m2ll2",
        "inf3-abe": "1t2m2tt2",
        "inf3-ins": "1t2m2n",
        "inf3-pass-ins": "1Dett2m2n",
        "inf4-nom": "1t2minen",
        "inf4-nom-poss": "1t2mise",
        "inf4-par": "1t2mist2",
        "inf5": "1t2m2isill2",  # +poss_suff
    },
    "fi-conj-kaivaa": {
    	"nargs": 4,
        "pres-1sg": "134n",
        "pres-2sg": "134t",
        "pres-3sg": "1244",
        "pres-1pl": "134mme",
        "pres-2pl": "134tte",
        "pres-3pl": "124v4t",
        "pres-pass": "13et44n",
        "pres-1sg-neg": "134",
        "pres-2sg-neg": "134",
        "pres-3sg-neg": "134",
        "pres-1pl-neg": "134",
        "pres-2pl-neg": "134",
        "pres-3pl-neg": "134",
        "pres-pass-neg": "13et4",
        "past-1sg": "134-Oin",
        "past-2sg": "134-Oit",
        "past-3sg": "124-Oi",
        "past-1pl": "134-Oimme",
        "past-2pl": "134-Oitte",
        "past-3pl": "124-Oiv4t",
        "past-pass": "13ettiin",
        "past-1sg-neg": "124nUt",
        "past-2sg-neg": "124nUt",
        "past-3sg-neg": "124nUt",
        "past-1pl-neg": "124neet",
        "past-2pl-neg": "124neet",
        "past-3pl-neg": "124neet",
        "past-pass-neg": "13ett4-U",
        "cond-1sg": "124isin",
        "cond-2sg": "124isit",
        "cond-3sg": "124isi",
        "cond-1pl": "124isimme",
        "cond-2pl": "124isitte",
        "cond-3pl": "124isiv4t",
        "cond-pass": "13ett4isiin",
        "cond-1sg-neg": "124isi",
        "cond-2sg-neg": "124isi",
        "cond-3sg-neg": "124isi",
        "cond-1pl-neg": "124isi",
        "cond-2pl-neg": "124isi",
        "cond-3pl-neg": "124isi",
        "cond-pass-neg": "13ett4isi",
        "impr-2sg": "134",
        "impr-3sg": "124kOOn",
        "impr-1pl": "124k44mme",
        "impr-2pl": "124k44",
        "impr-3pl": "124kOOt",
        "impr-pass": "13ett4kOOn",
        "impr-2sg-neg": "134",
        "impr-3sg-neg": "124kO",
        "impr-1pl-neg": "124kO",
        "impr-2pl-neg": "124kO",
        "impr-3pl-neg": "124kO",
        "impr-pass-neg": "13ett4kO",
        "potn-1sg": "124nen",
        "potn-2sg": "124net",
        "potn-3sg": "124nee",
        "potn-1pl": "124nemme",
        "potn-2pl": "124nette",
        "potn-3pl": "124nev4t",
        "potn-pass": "13ett4neen",
        "potn-1sg-neg": "124ne",
        "potn-2sg-neg": "124ne",
        "potn-3sg-neg": "124ne",
        "potn-1pl-neg": "124ne",
        "potn-2pl-neg": "124ne",
        "potn-3pl-neg": "124ne",
        "potn-pass-neg": "13ett4ne",
        "pres-part": "124v4",
        "pres-pass-part": "13ett4v4",
        "past-part": "124nUt",
        "past-pass-part": "13ett4-U",
        "agnt-part": "124m4",
        "nega-part": "124m4tOn",
        "inf1": "1244",
        "inf1-long": "1244kse",  # +poss_suff
        "inf2-ine": "124ess4",
        "inf2-pass-ine": "13ett4ess4",
        "inf2-ins": "124en",
        "inf3-ine": "124m4ss4",
        "inf3-ela": "124m4st4",
        "inf3-ill": "124m44n",
        "inf3-ade": "124m4ll4",
        "inf3-abe": "124m4tt4",
        "inf3-ins": "124m4n",
        "inf3-pass-ins": "13ett4m4n",
        "inf4-nom": "124minen",
        "inf4-nom-poss": "124mise",
        "inf4-par": "124mist4",
        "inf5": "124m4isill4",  # +poss_suff
    },
    "fi-conj-saartaa": {
    	"nargs": 2,
        "pres-1sg": "1D2n",
        "pres-2sg": "1D2t",
        "pres-3sg": "1t22",
        "pres-1pl": "1D2mme",
        "pres-2pl": "1D2tte",
        "pres-3pl": "1t2v2t",
        "pres-pass": "1Det22n",
        "pres-1sg-neg": "1D2",
        "pres-2sg-neg": "1D2",
        "pres-3sg-neg": "1D2",
        "pres-1pl-neg": "1D2",
        "pres-2pl-neg": "1D2",
        "pres-3pl-neg": "1D2",
        "pres-pass-neg": "1Det2",
        "past-1sg": ["1D2-Oin", "1sin"],
        "past-2sg": ["1D2-Oit", "1sit"],
        "past-3sg": ["1t2-Oi", "1si"],
        "past-1pl": ["1D2-Oimme", "1simme"],
        "past-2pl": ["1D2-Oitte", "1sitte"],
        "past-3pl": ["1t2-Oiv2t", "1siv2t"],
        "past-pass": "1Dettiin",
        "past-1sg-neg": "1t2nUt",
        "past-2sg-neg": "1t2nUt",
        "past-3sg-neg": "1t2nUt",
        "past-1pl-neg": "1t2neet",
        "past-2pl-neg": "1t2neet",
        "past-3pl-neg": "1t2neet",
        "past-pass-neg": "1Dett2-U",
        "cond-1sg": "1t2isin",
        "cond-2sg": "1t2isit",
        "cond-3sg": "1t2isi",
        "cond-1pl": "1t2isimme",
        "cond-2pl": "1t2isitte",
        "cond-3pl": "1t2isiv2t",
        "cond-pass": "1Dett2isiin",
        "cond-1sg-neg": "1t2isi",
        "cond-2sg-neg": "1t2isi",
        "cond-3sg-neg": "1t2isi",
        "cond-1pl-neg": "1t2isi",
        "cond-2pl-neg": "1t2isi",
        "cond-3pl-neg": "1t2isi",
        "cond-pass-neg": "1Dett2isi",
        "impr-2sg": "1D2",
        "impr-3sg": "1t2kOOn",
        "impr-1pl": "1t2k22mme",
        "impr-2pl": "1t2k22",
        "impr-3pl": "1t2kOOt",
        "impr-pass": "1Dett2kOOn",
        "impr-2sg-neg": "1D2",
        "impr-3sg-neg": "1t2kO",
        "impr-1pl-neg": "1t2kO",
        "impr-2pl-neg": "1t2kO",
        "impr-3pl-neg": "1t2kO",
        "impr-pass-neg": "1Dett2kO",
        "potn-1sg": "1t2nen",
        "potn-2sg": "1t2net",
        "potn-3sg": "1t2nee",
        "potn-1pl": "1t2nemme",
        "potn-2pl": "1t2nette",
        "potn-3pl": "1t2nev2t",
        "potn-pass": "1Dett2neen",
        "potn-1sg-neg": "1t2ne",
        "potn-2sg-neg": "1t2ne",
        "potn-3sg-neg": "1t2ne",
        "potn-1pl-neg": "1t2ne",
        "potn-2pl-neg": "1t2ne",
        "potn-3pl-neg": "1t2ne",
        "potn-pass-neg": "1Dett2ne",
        "pres-part": "1t2v2",
        "pres-pass-part": "1Dett2v2",
        "past-part": "1t2nUt",
        "past-pass-part": "1Dett2-U",
        "agnt-part": "1t2m2",
        "nega-part": "1t2m2tOn",
        "inf1": "1t22",
        "inf1-long": "1t22kse",  # +poss_suff
        "inf2-ine": "1t2ess2",
        "inf2-pass-ine": "1Dett2ess2",
        "inf2-ins": "1t2en",
        "inf3-ine": "1t2m2ss2",
        "inf3-ela": "1t2m2st2",
        "inf3-ill": "1t2m22n",
        "inf3-ade": "1t2m2ll2",
        "inf3-abe": "1t2m2tt2",
        "inf3-ins": "1t2m2n",
        "inf3-pass-ins": "1Dett2m2n",
        "inf4-nom": "1t2minen",
        "inf4-nom-poss": "1t2mise",
        "inf4-par": "1t2mist2",
        "inf5": "1t2m2isill2",  # +poss_suff
    },
    "fi-conj-laskea": {
    	"nargs": 4,
        "pres-1sg": "13en",
        "pres-2sg": "13et",
        "pres-3sg": "12ee",
        "pres-1pl": "13emme",
        "pres-2pl": "13ette",
        "pres-3pl": "12ev4t",
        "pres-pass": "13et44n",
        "pres-1sg-neg": "13e",
        "pres-2sg-neg": "13e",
        "pres-3sg-neg": "13e",
        "pres-1pl-neg": "13e",
        "pres-2pl-neg": "13e",
        "pres-3pl-neg": "13e",
        "pres-pass-neg": "13et4",
        "past-1sg": "13in",
        "past-2sg": "13it",
        "past-3sg": "12i",
        "past-1pl": "13imme",
        "past-2pl": "13itte",
        "past-3pl": "12iv4t",
        "past-pass": "13ettiin",
        "past-1sg-neg": "12en4-Ut",
        "past-2sg-neg": "12en4-Ut",
        "past-3sg-neg": "12en4-Ut",
        "past-1pl-neg": "12eneet",
        "past-2pl-neg": "12eneet",
        "past-3pl-neg": "12eneet",
        "past-pass-neg": "13ett4-U",
        "cond-1sg": "12isin",
        "cond-2sg": "12isit",
        "cond-3sg": "12isi",
        "cond-1pl": "12isimme",
        "cond-2pl": "12isitte",
        "cond-3pl": "12isiv4t",
        "cond-pass": "13ett4isiin",
        "cond-1sg-neg": "12isi",
        "cond-2sg-neg": "12isi",
        "cond-3sg-neg": "12isi",
        "cond-1pl-neg": "12isi",
        "cond-2pl-neg": "12isi",
        "cond-3pl-neg": "12isi",
        "cond-pass-neg": "13ett4isi",
        "impr-2sg": "13e",
        "impr-3sg": "12ek4-OOn",
        "impr-1pl": "12ek44mme",
        "impr-2pl": "12ek44",
        "impr-3pl": "12ek4-OOt",
        "impr-pass": "13ett4kOOn",
        "impr-2sg-neg": "13e",
        "impr-3sg-neg": "12ek4-O",
        "impr-1pl-neg": "12ek4-O",
        "impr-2pl-neg": "12ek4-O",
        "impr-3pl-neg": "12ek4-O",
        "impr-pass-neg": "13ett4kO",
        "potn-1sg": "12enen",
        "potn-2sg": "12enet",
        "potn-3sg": "12enee",
        "potn-1pl": "12enemme",
        "potn-2pl": "12enette",
        "potn-3pl": "12enev4t",
        "potn-pass": "13ett4neen",
        "potn-1sg-neg": "12ene",
        "potn-2sg-neg": "12ene",
        "potn-3sg-neg": "12ene",
        "potn-1pl-neg": "12ene",
        "potn-2pl-neg": "12ene",
        "potn-3pl-neg": "12ene",
        "potn-pass-neg": "13ett4ne",
        "pres-part": "12ev4",
        "pres-pass-part": "13ett4v4",
        "past-part": "12en4-Ut",
        "past-pass-part": "13ett4-U",
        "agnt-part": "12em4",
        "nega-part": "12em4tOn",
        "inf1": "12e4",
        "inf1-long": "12e4kse",  # +poss_suff
        "inf2-ine": "12iess4",
        "inf2-pass-ine": "13ett4ess4",
        "inf2-ins": "12ien",
        "inf3-ine": "12em4ss4",
        "inf3-ela": "12em4st4",
        "inf3-ill": "12em44n",
        "inf3-ade": "12em4ll4",
        "inf3-abe": "12em4tt4",
        "inf3-ins": "12em4n",
        "inf3-pass-ins": "13ett4m4n",
        "inf4-nom": "12eminen",
        "inf4-nom-poss": "12emise",
        "inf4-par": "12emist4",
        "inf5": "12em4isill4",  # +poss_suff
    },
    "fi-conj-tuntea": {
    	"nargs": 2,
        "pres-1sg": "1Den",
        "pres-2sg": "1Det",
        "pres-3sg": "1tee",
        "pres-1pl": "1Demme",
        "pres-2pl": "1Dette",
        "pres-3pl": "1tev2t",
        "pres-pass": "1Det22n",
        "pres-1sg-neg": "1De",
        "pres-2sg-neg": "1De",
        "pres-3sg-neg": "1De",
        "pres-1pl-neg": "1De",
        "pres-2pl-neg": "1De",
        "pres-3pl-neg": "1De",
        "pres-pass-neg": "1Det2",
        "past-1sg": ["1sin"],
        "past-2sg": ["1sit"],
        "past-3sg": ["1si"],
        "past-1pl": ["1simme"],
        "past-2pl": ["1sitte"],
        "past-3pl": ["1siv2t"],
        "past-pass": "1Dettiin",
        "past-1sg-neg": "1ten2-Ut",
        "past-2sg-neg": "1ten2-Ut",
        "past-3sg-neg": "1ten2-Ut",
        "past-1pl-neg": "1teneet",
        "past-2pl-neg": "1teneet",
        "past-3pl-neg": "1teneet",
        "past-pass-neg": "1Dett2-U",
        "cond-1sg": "1tisin",
        "cond-2sg": "1tisit",
        "cond-3sg": "1tisi",
        "cond-1pl": "1tisimme",
        "cond-2pl": "1tisitte",
        "cond-3pl": "1tisiv2t",
        "cond-pass": "1Dett2isiin",
        "cond-1sg-neg": "1tisi",
        "cond-2sg-neg": "1tisi",
        "cond-3sg-neg": "1tisi",
        "cond-1pl-neg": "1tisi",
        "cond-2pl-neg": "1tisi",
        "cond-3pl-neg": "1tisi",
        "cond-pass-neg": "1Dett2isi",
        "impr-2sg": "1De",
        "impr-3sg": "1tek2-OOn",
        "impr-1pl": "1tek22mme",
        "impr-2pl": "1tek22",
        "impr-3pl": "1tek2-OOt",
        "impr-pass": "1Dett2kOOn",
        "impr-2sg-neg": "1De",
        "impr-3sg-neg": "1tek2-O",
        "impr-1pl-neg": "1tek2-O",
        "impr-2pl-neg": "1tek2-O",
        "impr-3pl-neg": "1tek2-O",
        "impr-pass-neg": "1Dett2kO",
        "potn-1sg": "1tenen",
        "potn-2sg": "1tenet",
        "potn-3sg": "1tenee",
        "potn-1pl": "1tenemme",
        "potn-2pl": "1tenette",
        "potn-3pl": "1tenev2t",
        "potn-pass": "1Dett2neen",
        "potn-1sg-neg": "1tene",
        "potn-2sg-neg": "1tene",
        "potn-3sg-neg": "1tene",
        "potn-1pl-neg": "1tene",
        "potn-2pl-neg": "1tene",
        "potn-3pl-neg": "1tene",
        "potn-pass-neg": "1Dett2ne",
        "pres-part": "1tev2",
        "pres-pass-part": "1Dett2v2",
        "past-part": "1ten2-Ut",
        "past-pass-part": "1Dett2-U",
        "agnt-part": "1tem2",
        "nega-part": "1tem2tOn",
        "inf1": "1te2",
        "inf1-long": "1te2kse",  # +poss_suff
        "inf2-ine": "1tiess2",
        "inf2-pass-ine": "1Dett2ess2",
        "inf2-ins": "1tien",
        "inf3-ine": "1tem2ss2",
        "inf3-ela": "1tem2st2",
        "inf3-ill": "1tem22n",
        "inf3-ade": "1tem2ll2",
        "inf3-abe": "1tem2tt2",
        "inf3-ins": "1tem2n",
        "inf3-pass-ins": "1Dett2m2n",
        "inf4-nom": "1teminen",
        "inf4-nom-poss": "1temise",
        "inf4-par": "1temist2",
        "inf5": "1tem2isill2",  # +poss_suff
    },
    "fi-conj-lähteä": {
    	"nargs": 2,
        "pres-1sg": "1hDen",
        "pres-2sg": "1hDet",
        "pres-3sg": "1htee",
        "pres-1pl": "1hDemme",
        "pres-2pl": "1hDette",
        "pres-3pl": "1htev2t",
        "pres-pass": "1hDet22n",
        "pres-1sg-neg": "1hDe",
        "pres-2sg-neg": "1hDe",
        "pres-3sg-neg": "1hDe",
        "pres-1pl-neg": "1hDe",
        "pres-2pl-neg": "1hDe",
        "pres-3pl-neg": "1hDe",
        "pres-pass-neg": "1hDet2",
        "past-1sg": ["1hDin", "1ksin"],
        "past-2sg": ["1hDit", "1ksit"],
        "past-3sg": ["1hti", "1ksi"],
        "past-1pl": ["1hDimme", "1ksimme"],
        "past-2pl": ["1hDitte", "1ksitte"],
        "past-3pl": ["1htiv2t", "1ksiv2t"],
        "past-pass": "1hDettiin",
        "past-1sg-neg": "1hten2-Ut",
        "past-2sg-neg": "1hten2-Ut",
        "past-3sg-neg": "1hten2-Ut",
        "past-1pl-neg": "1hteneet",
        "past-2pl-neg": "1hteneet",
        "past-3pl-neg": "1hteneet",
        "past-pass-neg": "1hDett2-U",
        "cond-1sg": "1htisin",
        "cond-2sg": "1htisit",
        "cond-3sg": "1htisi",
        "cond-1pl": "1htisimme",
        "cond-2pl": "1htisitte",
        "cond-3pl": "1htisiv2t",
        "cond-pass": "1hDett2isiin",
        "cond-1sg-neg": "1htisi",
        "cond-2sg-neg": "1htisi",
        "cond-3sg-neg": "1htisi",
        "cond-1pl-neg": "1htisi",
        "cond-2pl-neg": "1htisi",
        "cond-3pl-neg": "1htisi",
        "cond-pass-neg": "1hDett2isi",
        "impr-2sg": "1hDe",
        "impr-3sg": "1htek2-OOn",
        "impr-1pl": "1htek22mme",
        "impr-2pl": "1htek22",
        "impr-3pl": "1htek2-OOt",
        "impr-pass": "1hDett2kOOn",
        "impr-2sg-neg": "1hDe",
        "impr-3sg-neg": "1htek2-O",
        "impr-1pl-neg": "1htek2-O",
        "impr-2pl-neg": "1htek2-O",
        "impr-3pl-neg": "1htek2-O",
        "impr-pass-neg": "1hDett2kO",
        "potn-1sg": "1htenen",
        "potn-2sg": "1htenet",
        "potn-3sg": "1htenee",
        "potn-1pl": "1htenemme",
        "potn-2pl": "1htenette",
        "potn-3pl": "1htenev2t",
        "potn-pass": "1hDett2neen",
        "potn-1sg-neg": "1htene",
        "potn-2sg-neg": "1htene",
        "potn-3sg-neg": "1htene",
        "potn-1pl-neg": "1htene",
        "potn-2pl-neg": "1htene",
        "potn-3pl-neg": "1htene",
        "potn-pass-neg": "1hDett2ne",
        "pres-part": "1htev2",
        "pres-pass-part": "1hDett2v2",
        "past-part": "1hten2-Ut",
        "past-pass-part": "1hDett2-U",
        "agnt-part": "1htem2",
        "nega-part": "1htem2tOn",
        "inf1": "1hte2",
        "inf1-long": "1hte2kse",  # +poss_suff
        "inf2-ine": "1htiess2",
        "inf2-pass-ine": "1hDett2ess2",
        "inf2-ins": "1htien",
        "inf3-ine": "1htem2ss2",
        "inf3-ela": "1htem2st2",
        "inf3-ill": "1htem22n",
        "inf3-ade": "1htem2ll2",
        "inf3-abe": "1htem2tt2",
        "inf3-ins": "1htem2n",
        "inf3-pass-ins": "1hDett2m2n",
        "inf4-nom": "1hteminen",
        "inf4-nom-poss": "1htemise",
        "inf4-par": "1htemist2",
        "inf5": "1htem2isill2",  # +poss_suff
    },
    "fi-conj-sallia": {
    	"nargs": 4,
        "pres-1sg": "13in",
        "pres-2sg": "13it",
        "pres-3sg": "12ii",
        "pres-1pl": "13imme",
        "pres-2pl": "13itte",
        "pres-3pl": "12iv4t",
        "pres-pass": "13it44n",
        "pres-1sg-neg": "13i",
        "pres-2sg-neg": "13i",
        "pres-3sg-neg": "13i",
        "pres-1pl-neg": "13i",
        "pres-2pl-neg": "13i",
        "pres-3pl-neg": "13i",
        "pres-pass-neg": "13it4",
        "past-1sg": "13in",
        "past-2sg": "13it",
        "past-3sg": "12i",
        "past-1pl": "13imme",
        "past-2pl": "13itte",
        "past-3pl": "12iv4t",
        "past-pass": "13ittiin",
        "past-1sg-neg": "12in4-Ut",
        "past-2sg-neg": "12in4-Ut",
        "past-3sg-neg": "12in4-Ut",
        "past-1pl-neg": "12ineet",
        "past-2pl-neg": "12ineet",
        "past-3pl-neg": "12ineet",
        "past-pass-neg": "13itt4-U",
        "cond-1sg": "12isin",
        "cond-2sg": "12isit",
        "cond-3sg": "12isi",
        "cond-1pl": "12isimme",
        "cond-2pl": "12isitte",
        "cond-3pl": "12isiv4t",
        "cond-pass": "13itt4isiin",
        "cond-1sg-neg": "12isi",
        "cond-2sg-neg": "12isi",
        "cond-3sg-neg": "12isi",
        "cond-1pl-neg": "12isi",
        "cond-2pl-neg": "12isi",
        "cond-3pl-neg": "12isi",
        "cond-pass-neg": "13itt4isi",
        "impr-2sg": "13i",
        "impr-3sg": "12ik4-OOn",
        "impr-1pl": "12ik44mme",
        "impr-2pl": "12ik44",
        "impr-3pl": "12ik4-OOt",
        "impr-pass": "13itt4kOOn",
        "impr-2sg-neg": "13i",
        "impr-3sg-neg": "12ik4-O",
        "impr-1pl-neg": "12ik4-O",
        "impr-2pl-neg": "12ik4-O",
        "impr-3pl-neg": "12ik4-O",
        "impr-pass-neg": "13itt4kO",
        "potn-1sg": "12inen",
        "potn-2sg": "12inet",
        "potn-3sg": "12inee",
        "potn-1pl": "12inemme",
        "potn-2pl": "12inette",
        "potn-3pl": "12inev4t",
        "potn-pass": "13itt4neen",
        "potn-1sg-neg": "12ine",
        "potn-2sg-neg": "12ine",
        "potn-3sg-neg": "12ine",
        "potn-1pl-neg": "12ine",
        "potn-2pl-neg": "12ine",
        "potn-3pl-neg": "12ine",
        "potn-pass-neg": "13itt4ne",
        "pres-part": "12iv4",
        "pres-pass-part": "13itt4v4",
        "past-part": "12in4-Ut",
        "past-pass-part": "13itt4-U",
        "agnt-part": "12im4",
        "nega-part": "12im4tOn",
        "inf1": "12i4",
        "inf1-long": "12i4kse",  # +poss_suff
        "inf2-ine": "12iess4",
        "inf2-pass-ine": "13itt4ess4",
        "inf2-ins": "12ien",
        "inf3-ine": "12im4ss4",
        "inf3-ela": "12im4st4",
        "inf3-ill": "12im44n",
        "inf3-ade": "12im4ll4",
        "inf3-abe": "12im4tt4",
        "inf3-ins": "12im4n",
        "inf3-pass-ins": "13itt4m4n",
        "inf4-nom": "12iminen",
        "inf4-nom-poss": "12imise",
        "inf4-par": "12imist4",
        "inf5": "12im4isill4",  # +poss_suff
    },
    "fi-conj-voida": {
    	"nargs": 2,
        "pres-1sg": "1n",
        "pres-2sg": "1t",
        "pres-3sg": "1",
        "pres-1pl": "1mme",
        "pres-2pl": "1tte",
        "pres-3pl": "1v2t",
        "pres-pass": "1D22n",
        "pres-1sg-neg": "1",
        "pres-2sg-neg": "1",
        "pres-3sg-neg": "1",
        "pres-1pl-neg": "1",
        "pres-2pl-neg": "1",
        "pres-3pl-neg": "1",
        "pres-pass-neg": "1D2",
        "past-1sg": ["1n"],
        "past-2sg": ["1t"],
        "past-3sg": ["1"],
        "past-1pl": ["1mme"],
        "past-2pl": ["1tte"],
        "past-3pl": ["1v2t"],
        "past-pass": "1tiin",
        "past-1sg-neg": "1n2-Ut",
        "past-2sg-neg": "1n2-Ut",
        "past-3sg-neg": "1n2-Ut",
        "past-1pl-neg": "1neet",
        "past-2pl-neg": "1neet",
        "past-3pl-neg": "1neet",
        "past-pass-neg": "1t2-U",
        "cond-1sg": "1sin",
        "cond-2sg": "1sit",
        "cond-3sg": "1si",
        "cond-1pl": "1simme",
        "cond-2pl": "1sitte",
        "cond-3pl": "1siv2t",
        "cond-pass": "1t2isiin",
        "cond-1sg-neg": "1si",
        "cond-2sg-neg": "1si",
        "cond-3sg-neg": "1si",
        "cond-1pl-neg": "1si",
        "cond-2pl-neg": "1si",
        "cond-3pl-neg": "1si",
        "cond-pass-neg": "1t2isi",
        "impr-2sg": "1",
        "impr-3sg": "1k2-OOn",
        "impr-1pl": "1k22mme",
        "impr-2pl": "1k22",
        "impr-3pl": "1k2-OOt",
        "impr-pass": "1t2kOOn",
        "impr-2sg-neg": "1",
        "impr-3sg-neg": "1k2-O",
        "impr-1pl-neg": "1k2-O",
        "impr-2pl-neg": "1k2-O",
        "impr-3pl-neg": "1k2-O",
        "impr-pass-neg": "1t2kO",
        "potn-1sg": "1nen",
        "potn-2sg": "1net",
        "potn-3sg": "1nee",
        "potn-1pl": "1nemme",
        "potn-2pl": "1nette",
        "potn-3pl": "1nev2t",
        "potn-pass": "1t2neen",
        "potn-1sg-neg": "1ne",
        "potn-2sg-neg": "1ne",
        "potn-3sg-neg": "1ne",
        "potn-1pl-neg": "1ne",
        "potn-2pl-neg": "1ne",
        "potn-3pl-neg": "1ne",
        "potn-pass-neg": "1t2ne",
        "pres-part": "1v2",
        "pres-pass-part": "1t2v2",
        "past-part": "1n2-Ut",
        "past-pass-part": "1t2-U",
        "agnt-part": "1m2",
        "nega-part": "1m2tOn",
        "inf1": "1D2",
        "inf1-long": "1D2kse",  # +poss_suff
        "inf2-ine": "1Dess2",
        "inf2-pass-ine": "1t2ess2",
        "inf2-ins": "1Den",
        "inf3-ine": "1m2ss2",
        "inf3-ela": "1m2st2",
        "inf3-ill": "1m22n",
        "inf3-ade": "1m2ll2",
        "inf3-abe": "1m2tt2",
        "inf3-ins": "1m2n",
        "inf3-pass-ins": "1t2m2n",
        "inf4-nom": "1minen",
        "inf4-nom-poss": "1mise",
        "inf4-par": "1mist2",
        "inf5": "1m2isill2",  # +poss_suff
    },
    "fi-conj-saada": {
    	"nargs": 2,
        "pres-1sg": "1n",
        "pres-2sg": "1t",
        "pres-3sg": "1",
        "pres-1pl": "1mme",
        "pres-2pl": "1tte",
        "pres-3pl": "1v2t",
        "pres-pass": "1D22n",
        "pres-1sg-neg": "1",
        "pres-2sg-neg": "1",
        "pres-3sg-neg": "1",
        "pres-1pl-neg": "1",
        "pres-2pl-neg": "1",
        "pres-3pl-neg": "1",
        "pres-pass-neg": "1D2",
        "past-1sg": ["1-in"],
        "past-2sg": ["1-it"],
        "past-3sg": ["1-i"],
        "past-1pl": ["1-imme"],
        "past-2pl": ["1-itte"],
        "past-3pl": ["1-iv2t"],
        "past-pass": "1tiin",
        "past-1sg-neg": "1n2-Ut",
        "past-2sg-neg": "1n2-Ut",
        "past-3sg-neg": "1n2-Ut",
        "past-1pl-neg": "1neet",
        "past-2pl-neg": "1neet",
        "past-3pl-neg": "1neet",
        "past-pass-neg": "1t2-U",
        "cond-1sg": "1-isin",
        "cond-2sg": "1-isit",
        "cond-3sg": "1-isi",
        "cond-1pl": "1-isimme",
        "cond-2pl": "1-isitte",
        "cond-3pl": "1-isiv2t",
        "cond-pass": "1t2isiin",
        "cond-1sg-neg": "1-isi",
        "cond-2sg-neg": "1-isi",
        "cond-3sg-neg": "1-isi",
        "cond-1pl-neg": "1-isi",
        "cond-2pl-neg": "1-isi",
        "cond-3pl-neg": "1-isi",
        "cond-pass-neg": "1t2isi",
        "impr-2sg": "1",
        "impr-3sg": "1k2-OOn",
        "impr-1pl": "1k22mme",
        "impr-2pl": "1k22",
        "impr-3pl": "1k2-OOt",
        "impr-pass": "1t2kOOn",
        "impr-2sg-neg": "1",
        "impr-3sg-neg": "1k2-O",
        "impr-1pl-neg": "1k2-O",
        "impr-2pl-neg": "1k2-O",
        "impr-3pl-neg": "1k2-O",
        "impr-pass-neg": "1t2kO",
        "potn-1sg": "1nen",
        "potn-2sg": "1net",
        "potn-3sg": "1nee",
        "potn-1pl": "1nemme",
        "potn-2pl": "1nette",
        "potn-3pl": "1nev2t",
        "potn-pass": "1t2neen",
        "potn-1sg-neg": "1ne",
        "potn-2sg-neg": "1ne",
        "potn-3sg-neg": "1ne",
        "potn-1pl-neg": "1ne",
        "potn-2pl-neg": "1ne",
        "potn-3pl-neg": "1ne",
        "potn-pass-neg": "1t2ne",
        "pres-part": "1v2",
        "pres-pass-part": "1t2v2",
        "past-part": "1n2-Ut",
        "past-pass-part": "1t2-U",
        "agnt-part": "1m2",
        "nega-part": "1m2tOn",
        "inf1": "1D2",
        "inf1-long": "1D2kse",  # +poss_suff
        "inf2-ine": "1Dess2",
        "inf2-pass-ine": "1t2ess2",
        "inf2-ins": "1Den",
        "inf3-ine": "1m2ss2",
        "inf3-ela": "1m2st2",
        "inf3-ill": "1m22n",
        "inf3-ade": "1m2ll2",
        "inf3-abe": "1m2tt2",
        "inf3-ins": "1m2n",
        "inf3-pass-ins": "1t2m2n",
        "inf4-nom": "1minen",
        "inf4-nom-poss": "1mise",
        "inf4-par": "1mist2",
        "inf5": "1m2isill2",  # +poss_suff
    },
    "fi-conj-juoda": {
    	"nargs": 2,
        "pres-1sg": "1n",
        "pres-2sg": "1t",
        "pres-3sg": "1",
        "pres-1pl": "1mme",
        "pres-2pl": "1tte",
        "pres-3pl": "1v2t",
        "pres-pass": "1D22n",
        "pres-1sg-neg": "1",
        "pres-2sg-neg": "1",
        "pres-3sg-neg": "1",
        "pres-1pl-neg": "1",
        "pres-2pl-neg": "1",
        "pres-3pl-neg": "1",
        "pres-pass-neg": "1D2",
        "past-1sg": ["1/in"],
        "past-2sg": ["1/it"],
        "past-3sg": ["1/i"],
        "past-1pl": ["1/imme"],
        "past-2pl": ["1/itte"],
        "past-3pl": ["1/iv2t"],
        "past-pass": "1tiin",
        "past-1sg-neg": "1n2-Ut",
        "past-2sg-neg": "1n2-Ut",
        "past-3sg-neg": "1n2-Ut",
        "past-1pl-neg": "1neet",
        "past-2pl-neg": "1neet",
        "past-3pl-neg": "1neet",
        "past-pass-neg": "1t2-U",
        "cond-1sg": "1/isin",
        "cond-2sg": "1/isit",
        "cond-3sg": "1/isi",
        "cond-1pl": "1/isimme",
        "cond-2pl": "1/isitte",
        "cond-3pl": "1/isiv2t",
        "cond-pass": "1t2isiin",
        "cond-1sg-neg": "1/isi",
        "cond-2sg-neg": "1/isi",
        "cond-3sg-neg": "1/isi",
        "cond-1pl-neg": "1/isi",
        "cond-2pl-neg": "1/isi",
        "cond-3pl-neg": "1/isi",
        "cond-pass-neg": "1t2isi",
        "impr-2sg": "1",
        "impr-3sg": "1k2-OOn",
        "impr-1pl": "1k22mme",
        "impr-2pl": "1k22",
        "impr-3pl": "1k2-OOt",
        "impr-pass": "1t2kOOn",
        "impr-2sg-neg": "1",
        "impr-3sg-neg": "1k2-O",
        "impr-1pl-neg": "1k2-O",
        "impr-2pl-neg": "1k2-O",
        "impr-3pl-neg": "1k2-O",
        "impr-pass-neg": "1t2kO",
        "potn-1sg": "1nen",
        "potn-2sg": "1net",
        "potn-3sg": "1nee",
        "potn-1pl": "1nemme",
        "potn-2pl": "1nette",
        "potn-3pl": "1nev2t",
        "potn-pass": "1t2neen",
        "potn-1sg-neg": "1ne",
        "potn-2sg-neg": "1ne",
        "potn-3sg-neg": "1ne",
        "potn-1pl-neg": "1ne",
        "potn-2pl-neg": "1ne",
        "potn-3pl-neg": "1ne",
        "potn-pass-neg": "1t2ne",
        "pres-part": "1v2",
        "pres-pass-part": "1t2v2",
        "past-part": "1n2-Ut",
        "past-pass-part": "1t2-U",
        "agnt-part": "1m2",
        "nega-part": "1m2tOn",
        "inf1": "1D2",
        "inf1-long": "1D2kse",  # +poss_suff
        "inf2-ine": "1Dess2",
        "inf2-pass-ine": "1t2ess2",
        "inf2-ins": "1Den",
        "inf3-ine": "1m2ss2",
        "inf3-ela": "1m2st2",
        "inf3-ill": "1m22n",
        "inf3-ade": "1m2ll2",
        "inf3-abe": "1m2tt2",
        "inf3-ins": "1m2n",
        "inf3-pass-ins": "1t2m2n",
        "inf4-nom": "1minen",
        "inf4-nom-poss": "1mise",
        "inf4-par": "1mist2",
        "inf5": "1m2isill2",  # +poss_suff
    },
    "fi-conj-käydä": {
    	"nargs": 2,
        "pres-1sg": "1n",
        "pres-2sg": "1t",
        "pres-3sg": "1",
        "pres-1pl": "1mme",
        "pres-2pl": "1tte",
        "pres-3pl": "1v2t",
        "pres-pass": "1D22n",
        "pres-1sg-neg": "1",
        "pres-2sg-neg": "1",
        "pres-3sg-neg": "1",
        "pres-1pl-neg": "1",
        "pres-2pl-neg": "1",
        "pres-3pl-neg": "1",
        "pres-pass-neg": "1D2",
        "past-1sg": ["1-vin"],
        "past-2sg": ["1-vit"],
        "past-3sg": ["1-vi"],
        "past-1pl": ["1-vimme"],
        "past-2pl": ["1-vitte"],
        "past-3pl": ["1-viv2t"],
        "past-pass": "1tiin",
        "past-1sg-neg": "1n2-Ut",
        "past-2sg-neg": "1n2-Ut",
        "past-3sg-neg": "1n2-Ut",
        "past-1pl-neg": "1neet",
        "past-2pl-neg": "1neet",
        "past-3pl-neg": "1neet",
        "past-pass-neg": "1t2-U",
        "cond-1sg": "1-visin",
        "cond-2sg": "1-visit",
        "cond-3sg": "1-visi",
        "cond-1pl": "1-visimme",
        "cond-2pl": "1-visitte",
        "cond-3pl": "1-visiv2t",
        "cond-pass": "1t2isiin",
        "cond-1sg-neg": "1-visi",
        "cond-2sg-neg": "1-visi",
        "cond-3sg-neg": "1-visi",
        "cond-1pl-neg": "1-visi",
        "cond-2pl-neg": "1-visi",
        "cond-3pl-neg": "1-visi",
        "cond-pass-neg": "1t2isi",
        "impr-2sg": "1",
        "impr-3sg": "1k2-OOn",
        "impr-1pl": "1k22mme",
        "impr-2pl": "1k22",
        "impr-3pl": "1k2-OOt",
        "impr-pass": "1t2kOOn",
        "impr-2sg-neg": "1",
        "impr-3sg-neg": "1k2-O",
        "impr-1pl-neg": "1k2-O",
        "impr-2pl-neg": "1k2-O",
        "impr-3pl-neg": "1k2-O",
        "impr-pass-neg": "1t2kO",
        "potn-1sg": "1nen",
        "potn-2sg": "1net",
        "potn-3sg": "1nee",
        "potn-1pl": "1nemme",
        "potn-2pl": "1nette",
        "potn-3pl": "1nev2t",
        "potn-pass": "1t2neen",
        "potn-1sg-neg": "1ne",
        "potn-2sg-neg": "1ne",
        "potn-3sg-neg": "1ne",
        "potn-1pl-neg": "1ne",
        "potn-2pl-neg": "1ne",
        "potn-3pl-neg": "1ne",
        "potn-pass-neg": "1t2ne",
        "pres-part": "1v2",
        "pres-pass-part": "1t2v2",
        "past-part": "1n2-Ut",
        "past-pass-part": "1t2-U",
        "agnt-part": "1m2",
        "nega-part": "1m2tOn",
        "inf1": "1D2",
        "inf1-long": "1D2kse",  # +poss_suff
        "inf2-ine": "1Dess2",
        "inf2-pass-ine": "1t2ess2",
        "inf2-ins": "1Den",
        "inf3-ine": "1m2ss2",
        "inf3-ela": "1m2st2",
        "inf3-ill": "1m22n",
        "inf3-ade": "1m2ll2",
        "inf3-abe": "1m2tt2",
        "inf3-ins": "1m2n",
        "inf3-pass-ins": "1t2m2n",
        "inf4-nom": "1minen",
        "inf4-nom-poss": "1mise",
        "inf4-par": "1mist2",
        "inf5": "1m2isill2",  # +poss_suff
    },
    "fi-conj-rohkaista": {
    	"nargs": 5,
        "pres-1sg": "134sen",
        "pres-2sg": "134set",
        "pres-3sg": "134see",
        "pres-1pl": "134semme",
        "pres-2pl": "134sette",
        "pres-3pl": "134sev5t",
        "pres-pass": "124st55n",
        "pres-1sg-neg": "134se",
        "pres-2sg-neg": "134se",
        "pres-3sg-neg": "134se",
        "pres-1pl-neg": "134se",
        "pres-2pl-neg": "134se",
        "pres-3pl-neg": "134se",
        "pres-pass-neg": "124st5",
        "past-1sg": "134sin",
        "past-2sg": "134sit",
        "past-3sg": "134si",
        "past-1pl": "134simme",
        "past-2pl": "134sitte",
        "past-3pl": "134siv5t",
        "past-pass": "124stiin",
        "past-1sg-neg": "124ss5-Ut",
        "past-2sg-neg": "124ss5-Ut",
        "past-3sg-neg": "124ss5-Ut",
        "past-1pl-neg": "124sseet",
        "past-2pl-neg": "124sseet",
        "past-3pl-neg": "124sseet",
        "past-pass-neg": "124st5-U",
        "cond-1sg": "134sisin",
        "cond-2sg": "134sisit",
        "cond-3sg": "134sisi",
        "cond-1pl": "134sisimme",
        "cond-2pl": "134sisitte",
        "cond-3pl": "134sisiv5t",
        "cond-pass": "124st5isiin",
        "cond-1sg-neg": "134sisi",
        "cond-2sg-neg": "134sisi",
        "cond-3sg-neg": "134sisi",
        "cond-1pl-neg": "134sisi",
        "cond-2pl-neg": "134sisi",
        "cond-3pl-neg": "134sisi",
        "cond-pass-neg": "124st5isi",
        "impr-2sg": "134se",
        "impr-3sg": "124sk5-OOn",
        "impr-1pl": "124sk55mme",
        "impr-2pl": "124sk55",
        "impr-3pl": "124sk5-OOt",
        "impr-pass": "124st5kOOn",
        "impr-2sg-neg": "134se",
        "impr-3sg-neg": "124sk5-O",
        "impr-1pl-neg": "124sk5-O",
        "impr-2pl-neg": "124sk5-O",
        "impr-3pl-neg": "124sk5-O",
        "impr-pass-neg": "124st5kO",
        "potn-1sg": "124ssen",
        "potn-2sg": "124sset",
        "potn-3sg": "124ssee",
        "potn-1pl": "124ssemme",
        "potn-2pl": "124ssette",
        "potn-3pl": "124ssev5t",
        "potn-pass": "124st5neen",
        "potn-1sg-neg": "124sse",
        "potn-2sg-neg": "124sse",
        "potn-3sg-neg": "124sse",
        "potn-1pl-neg": "124sse",
        "potn-2pl-neg": "124sse",
        "potn-3pl-neg": "124sse",
        "potn-pass-neg": "124st5ne",
        "pres-part": "134sev5",
        "pres-pass-part": "124st5v5",
        "past-part": "124ss5-Ut",
        "past-pass-part": "124st5-U",
        "agnt-part": "134sem5",
        "nega-part": "134sem5tOn",
        "inf1": "124st5",
        "inf1-long": "124st5kse",  # +poss_suff
        "inf2-ine": "124stess5",
        "inf2-pass-ine": "124st5ess5",
        "inf2-ins": "124sten",
        "inf3-ine": "134sem5ss5",
        "inf3-ela": "134sem5st5",
        "inf3-ill": "134sem55n",
        "inf3-ade": "134sem5ll5",
        "inf3-abe": "134sem5tt5",
        "inf3-ins": "134sem5n",
        "inf3-pass-ins": "124st5m5n",
        "inf4-nom": "134seminen",
        "inf4-nom-poss": "134semise",
        "inf4-par": "134semist5",
        "inf5": "134sem5isill5",  # +poss_suff
    },
    "fi-conj-tulla": {
    	"nargs": 5,
        "pres-1sg": "134en",
        "pres-2sg": "134et",
        "pres-3sg": "134ee",
        "pres-1pl": "134emme",
        "pres-2pl": "134ette",
        "pres-3pl": "134ev5t",
        "pres-pass": "124D55n",
        "pres-1sg-neg": "134e",
        "pres-2sg-neg": "134e",
        "pres-3sg-neg": "134e",
        "pres-1pl-neg": "134e",
        "pres-2pl-neg": "134e",
        "pres-3pl-neg": "134e",
        "pres-pass-neg": "124D5",
        "past-1sg": "134in",
        "past-2sg": "134it",
        "past-3sg": "134i",
        "past-1pl": "134imme",
        "past-2pl": "134itte",
        "past-3pl": "134iv5t",
        "past-pass": "124tiin",
        "past-1sg-neg": "124D5-Ut",
        "past-2sg-neg": "124D5-Ut",
        "past-3sg-neg": "124D5-Ut",
        "past-1pl-neg": "124Deet",
        "past-2pl-neg": "124Deet",
        "past-3pl-neg": "124Deet",
        "past-pass-neg": "124t5-U",
        "cond-1sg": "134isin",
        "cond-2sg": "134isit",
        "cond-3sg": "134isi",
        "cond-1pl": "134isimme",
        "cond-2pl": "134isitte",
        "cond-3pl": "134isiv5t",
        "cond-pass": "124t5isiin",
        "cond-1sg-neg": "134isi",
        "cond-2sg-neg": "134isi",
        "cond-3sg-neg": "134isi",
        "cond-1pl-neg": "134isi",
        "cond-2pl-neg": "134isi",
        "cond-3pl-neg": "134isi",
        "cond-pass-neg": "124t5isi",
        "impr-2sg": "134e",
        "impr-3sg": "124k5-OOn",
        "impr-1pl": "124k55mme",
        "impr-2pl": "124k55",
        "impr-3pl": "124k5-OOt",
        "impr-pass": "124t5kOOn",
        "impr-2sg-neg": "134e",
        "impr-3sg-neg": "124k5-O",
        "impr-1pl-neg": "124k5-O",
        "impr-2pl-neg": "124k5-O",
        "impr-3pl-neg": "124k5-O",
        "impr-pass-neg": "124t5kO",
        "potn-1sg": "124Den",
        "potn-2sg": "124Det",
        "potn-3sg": "124Dee",
        "potn-1pl": "124Demme",
        "potn-2pl": "124Dette",
        "potn-3pl": "124Dev5t",
        "potn-pass": "124t5neen",
        "potn-1sg-neg": "124De",
        "potn-2sg-neg": "124De",
        "potn-3sg-neg": "124De",
        "potn-1pl-neg": "124De",
        "potn-2pl-neg": "124De",
        "potn-3pl-neg": "124De",
        "potn-pass-neg": "124t5ne",
        "pres-part": "134ev5",
        "pres-pass-part": "124t5v5",
        "past-part": "124D5-Ut",
        "past-pass-part": "124t5-U",
        "agnt-part": "134em5",
        "nega-part": "134em5tOn",
        "inf1": "124D5",
        "inf1-long": "124D5kse",  # +poss_suff
        "inf2-ine": "124Dess5",
        "inf2-pass-ine": "124t5ess5",
        "inf2-ins": "124Den",
        "inf3-ine": "134em5ss5",
        "inf3-ela": "134em5st5",
        "inf3-ill": "134em55n",
        "inf3-ade": "134em5ll5",
        "inf3-abe": "134em5tt5",
        "inf3-ins": "134em5n",
        "inf3-pass-ins": "124t5m5n",
        "inf4-nom": "134eminen",
        "inf4-nom-poss": "134emise",
        "inf4-par": "134emist5",
        "inf5": "134em5isill5",  # +poss_suff
    },
    "fi-conj-tupakoida": {
    	"nargs": 2,
        "pres-1sg": ["1n", "1tsen"],
        "pres-2sg": ["1t", "1tset"],
        "pres-3sg": ["1", "1tsee"],
        "pres-1pl": ["1mme", "1tsemme"],
        "pres-2pl": ["1tte", "1tsette"],
        "pres-3pl": ["1v2t", "1tsev2t"],
        "pres-pass": "1D22n",
        "pres-1sg-neg": ["1", "1tse"],
        "pres-2sg-neg": ["1", "1tse"],
        "pres-3sg-neg": ["1", "1tse"],
        "pres-1pl-neg": ["1", "1tse"],
        "pres-2pl-neg": ["1", "1tse"],
        "pres-3pl-neg": ["1", "1tse"],
        "pres-pass-neg": "1D2",
        "past-1sg": ["1n", "1tsin"],
        "past-2sg": ["1t", "1tsit"],
        "past-3sg": ["1", "1tsi"],
        "past-1pl": ["1mme", "1tsimme"],
        "past-2pl": ["1tte", "1tsitte"],
        "past-3pl": ["1v2t", "1tsiv2t"],
        "past-pass": "1tiin",
        "past-1sg-neg": "1n2-Ut",
        "past-2sg-neg": "1n2-Ut",
        "past-3sg-neg": "1n2-Ut",
        "past-1pl-neg": "1neet",
        "past-2pl-neg": "1neet",
        "past-3pl-neg": "1neet",
        "past-pass-neg": "1t2-U",
        "cond-1sg": ["1sin", "1tsisin"],
        "cond-2sg": ["1sit", "1tsisit"],
        "cond-3sg": ["1si", "1tsisi"],
        "cond-1pl": ["1simme", "1tsisimme"],
        "cond-2pl": ["1sitte", "1tsisitte"],
        "cond-3pl": ["1siv2t", "1tsisiv2t"],
        "cond-pass": "1t2isiin",
        "cond-1sg-neg": ["1si", "1tsisi"],
        "cond-2sg-neg": ["1si", "1tsisi"],
        "cond-3sg-neg": ["1si", "1tsisi"],
        "cond-1pl-neg": ["1si", "1tsisi"],
        "cond-2pl-neg": ["1si", "1tsisi"],
        "cond-3pl-neg": ["1si", "1tsisi"],
        "cond-pass-neg": "1t2isi",
        "impr-2sg": ["1", "1tse"],
        "impr-3sg": "1k2-OOn",
        "impr-1pl": "1k22mme",
        "impr-2pl": "1k22",
        "impr-3pl": "1k2-OOt",
        "impr-pass": "1t2kOOn",
        "impr-2sg-neg": ["1", "1tse"],
        "impr-3sg-neg": "1k2-O",
        "impr-1pl-neg": "1k2-O",
        "impr-2pl-neg": "1k2-O",
        "impr-3pl-neg": "1k2-O",
        "impr-pass-neg": "1t2kO",
        "potn-1sg": "1nen",
        "potn-2sg": "1net",
        "potn-3sg": "1nee",
        "potn-1pl": "1nemme",
        "potn-2pl": "1nette",
        "potn-3pl": "1nev2t",
        "potn-pass": "1t2neen",
        "potn-1sg-neg": "1ne",
        "potn-2sg-neg": "1ne",
        "potn-3sg-neg": "1ne",
        "potn-1pl-neg": "1ne",
        "potn-2pl-neg": "1ne",
        "potn-3pl-neg": "1ne",
        "potn-pass-neg": "1t2ne",
        "pres-part": ["1v2", "1tsev2"],
        "pres-pass-part": "1t2v2",
        "past-part": "1n2-Ut",
        "past-pass-part": "1t2-U",
        "agnt-part": ["1m2", "1tsem2"],
        "nega-part": ["1m2tOn", "1tsem2tOn"],
        "inf1": "1D2",
        "inf1-long": "1D2kse",  # +poss_suff
        "inf2-ine": "1Dess2",
        "inf2-pass-ine": "1t2ess2",
        "inf2-ins": "1Den",
        "inf3-ine": ["1m2ss2", "1tsem2ss2"],
        "inf3-ela": ["1m2st2", "1tsem2st2"],
        "inf3-ill": ["1m22n", "1tsem22n"],
        "inf3-ade": ["1m2ll2", "1tsem2ll2"],
        "inf3-abe": ["1m2tt2", "1tsem2tt2"],
        "inf3-ins": ["1m2n", "1tsem2n"],
        "inf3-pass-ins": "1t2m2n",
        "inf4-nom": ["1minen", "1tseminen"],
        "inf4-nom-poss": ["1mise", "1tsemise"],
        "inf4-par": ["1mist2", "1tsemist2"],
        "inf5": ["1m2isill2", "1tsem2isill2"], # +poss_suff
    },
    "fi-conj-valita": {
    	"nargs": 2,
        "pres-1sg": ["1tsen"],
        "pres-2sg": ["1tset"],
        "pres-3sg": ["1tsee"],
        "pres-1pl": ["1tsemme"],
        "pres-2pl": ["1tsette"],
        "pres-3pl": ["1tsev2t"],
        "pres-pass": "1t22n",
        "pres-1sg-neg": ["1tse"],
        "pres-2sg-neg": ["1tse"],
        "pres-3sg-neg": ["1tse"],
        "pres-1pl-neg": ["1tse"],
        "pres-2pl-neg": ["1tse"],
        "pres-3pl-neg": ["1tse"],
        "pres-pass-neg": "1t2",
        "past-1sg": ["1tsin"],
        "past-2sg": ["1tsit"],
        "past-3sg": ["1tsi"],
        "past-1pl": ["1tsimme"],
        "past-2pl": ["1tsitte"],
        "past-3pl": ["1tsiv2t"],
        "past-pass": "1ttiin",
        "past-1sg-neg": "1nn2-Ut",
        "past-2sg-neg": "1nn2-Ut",
        "past-3sg-neg": "1nn2-Ut",
        "past-1pl-neg": "1nneet",
        "past-2pl-neg": "1nneet",
        "past-3pl-neg": "1nneet",
        "past-pass-neg": "1tt2-U",
        "cond-1sg": ["1tsisin"],
        "cond-2sg": ["1tsisit"],
        "cond-3sg": ["1tsisi"],
        "cond-1pl": ["1tsisimme"],
        "cond-2pl": ["1tsisitte"],
        "cond-3pl": ["1tsisiv2t"],
        "cond-pass": "1tt2isiin",
        "cond-1sg-neg": ["1tsisi"],
        "cond-2sg-neg": ["1tsisi"],
        "cond-3sg-neg": ["1tsisi"],
        "cond-1pl-neg": ["1tsisi"],
        "cond-2pl-neg": ["1tsisi"],
        "cond-3pl-neg": ["1tsisi"],
        "cond-pass-neg": "1tt2isi",
        "impr-2sg": ["1tse"],
        "impr-3sg": "1tk2-OOn",
        "impr-1pl": "1tk22mme",
        "impr-2pl": "1tk22",
        "impr-3pl": "1tk2-OOt",
        "impr-pass": "1tt2kOOn",
        "impr-2sg-neg": ["1tse"],
        "impr-3sg-neg": "1tk2-O",
        "impr-1pl-neg": "1tk2-O",
        "impr-2pl-neg": "1tk2-O",
        "impr-3pl-neg": "1tk2-O",
        "impr-pass-neg": "1tt2kO",
        "potn-1sg": "1nnen",
        "potn-2sg": "1nnet",
        "potn-3sg": "1nnee",
        "potn-1pl": "1nnemme",
        "potn-2pl": "1nnette",
        "potn-3pl": "1nnev2t",
        "potn-pass": "1tt2neen",
        "potn-1sg-neg": "1nne",
        "potn-2sg-neg": "1nne",
        "potn-3sg-neg": "1nne",
        "potn-1pl-neg": "1nne",
        "potn-2pl-neg": "1nne",
        "potn-3pl-neg": "1nne",
        "potn-pass-neg": "1tt2ne",
        "pres-part": ["1tsev2"],
        "pres-pass-part": "1tt2v2",
        "past-part": "1nn2-Ut",
        "past-pass-part": "1tt2-U",
        "agnt-part": ["1tsem2"],
        "nega-part": ["1tsem2tOn"],
        "inf1": "1t2",
        "inf1-long": "1t2kse",  # +poss_suff
        "inf2-ine": "1tess2",
        "inf2-pass-ine": "1tt2ess2",
        "inf2-ins": "1ten",
        "inf3-ine": ["1tsem2ss2"],
        "inf3-ela": ["1tsem2st2"],
        "inf3-ill": ["1tsem22n"],
        "inf3-ade": ["1tsem2ll2"],
        "inf3-abe": ["1tsem2tt2"],
        "inf3-ins": ["1tsem2n"],
        "inf3-pass-ins": "1tt2m2n",
        "inf4-nom": ["1tseminen"],
        "inf4-nom-poss": ["1tsemise"],
        "inf4-par": ["1tsemist2"],
        "inf5": ["1tsem2isill2"], # +poss_suff
    },
    "fi-conj-juosta": {
    	"nargs": 2,
        "pres-1sg": ["1ksen"],
        "pres-2sg": ["1kset"],
        "pres-3sg": ["1ksee"],
        "pres-1pl": ["1ksemme"],
        "pres-2pl": ["1ksette"],
        "pres-3pl": ["1ksev2t"],
        "pres-pass": "1st22n",
        "pres-1sg-neg": ["1kse"],
        "pres-2sg-neg": ["1kse"],
        "pres-3sg-neg": ["1kse"],
        "pres-1pl-neg": ["1kse"],
        "pres-2pl-neg": ["1kse"],
        "pres-3pl-neg": ["1kse"],
        "pres-pass-neg": "1st2",
        "past-1sg": ["1ksin"],
        "past-2sg": ["1ksit"],
        "past-3sg": ["1ksi"],
        "past-1pl": ["1ksimme"],
        "past-2pl": ["1ksitte"],
        "past-3pl": ["1ksiv2t"],
        "past-pass": "1stiin",
        "past-1sg-neg": "1ss2-Ut",
        "past-2sg-neg": "1ss2-Ut",
        "past-3sg-neg": "1ss2-Ut",
        "past-1pl-neg": "1sseet",
        "past-2pl-neg": "1sseet",
        "past-3pl-neg": "1sseet",
        "past-pass-neg": "1st2-U",
        "cond-1sg": ["1ksisin"],
        "cond-2sg": ["1ksisit"],
        "cond-3sg": ["1ksisi"],
        "cond-1pl": ["1ksisimme"],
        "cond-2pl": ["1ksisitte"],
        "cond-3pl": ["1ksisiv2t"],
        "cond-pass": "1st2isiin",
        "cond-1sg-neg": ["1ksisi"],
        "cond-2sg-neg": ["1ksisi"],
        "cond-3sg-neg": ["1ksisi"],
        "cond-1pl-neg": ["1ksisi"],
        "cond-2pl-neg": ["1ksisi"],
        "cond-3pl-neg": ["1ksisi"],
        "cond-pass-neg": "1st2isi",
        "impr-2sg": ["1kse"],
        "impr-3sg": "1sk2-OOn",
        "impr-1pl": "1sk22mme",
        "impr-2pl": "1sk22",
        "impr-3pl": "1sk2-OOt",
        "impr-pass": "1st2kOOn",
        "impr-2sg-neg": ["1kse"],
        "impr-3sg-neg": "1sk2-O",
        "impr-1pl-neg": "1sk2-O",
        "impr-2pl-neg": "1sk2-O",
        "impr-3pl-neg": "1sk2-O",
        "impr-pass-neg": "1st2kO",
        "potn-1sg": "1ssen",
        "potn-2sg": "1sset",
        "potn-3sg": "1ssee",
        "potn-1pl": "1ssemme",
        "potn-2pl": "1ssette",
        "potn-3pl": "1ssev2t",
        "potn-pass": "1st2neen",
        "potn-1sg-neg": "1sse",
        "potn-2sg-neg": "1sse",
        "potn-3sg-neg": "1sse",
        "potn-1pl-neg": "1sse",
        "potn-2pl-neg": "1sse",
        "potn-3pl-neg": "1sse",
        "potn-pass-neg": "1st2ne",
        "pres-part": ["1ksev2"],
        "pres-pass-part": "1st2v2",
        "past-part": "1ss2-Ut",
        "past-pass-part": "1st2-U",
        "agnt-part": ["1ksem2"],
        "nega-part": ["1ksem2tOn"],
        "inf1": "1st2",
        "inf1-long": "1st2kse",  # +poss_suff
        "inf2-ine": "1stess2",
        "inf2-pass-ine": "1st2ess2",
        "inf2-ins": "1sten",
        "inf3-ine": ["1ksem2ss2"],
        "inf3-ela": ["1ksem2st2"],
        "inf3-ill": ["1ksem22n"],
        "inf3-ade": ["1ksem2ll2"],
        "inf3-abe": ["1ksem2tt2"],
        "inf3-ins": ["1ksem2n"],
        "inf3-pass-ins": "1st2m2n",
        "inf4-nom": ["1kseminen"],
        "inf4-nom-poss": ["1ksemise"],
        "inf4-par": ["1ksemist2"],
        "inf5": ["1ksem2isill2"], # +poss_suff
    },
    "fi-conj-nähdä": {
    	"nargs": 2,
        "pres-1sg": "1en",
        "pres-2sg": "1et",
        "pres-3sg": "1kee",
        "pres-1pl": "1emme",
        "pres-2pl": "1ette",
        "pres-3pl": "1kev2t",
        "pres-pass": "1hd22n",
        "pres-1sg-neg": "1e",
        "pres-2sg-neg": "1e",
        "pres-3sg-neg": "1e",
        "pres-1pl-neg": "1e",
        "pres-2pl-neg": "1e",
        "pres-3pl-neg": "1e",
        "pres-pass-neg": "1hd2",
        "past-1sg": ["1in"],
        "past-2sg": ["1it"],
        "past-3sg": ["1ki"],
        "past-1pl": ["1imme"],
        "past-2pl": ["1itte"],
        "past-3pl": ["1kiv2t"],
        "past-pass": "1htiin",
        "past-1sg-neg": "1hn2-Ut",
        "past-2sg-neg": "1hn2-Ut",
        "past-3sg-neg": "1hn2-Ut",
        "past-1pl-neg": "1hneet",
        "past-2pl-neg": "1hneet",
        "past-3pl-neg": "1hneet",
        "past-pass-neg": "1ht2-U",
        "cond-1sg": "1kisin",
        "cond-2sg": "1kisit",
        "cond-3sg": "1kisi",
        "cond-1pl": "1kisimme",
        "cond-2pl": "1kisitte",
        "cond-3pl": "1kisiv2t",
        "cond-pass": "1ht2isiin",
        "cond-1sg-neg": "1kisi",
        "cond-2sg-neg": "1kisi",
        "cond-3sg-neg": "1kisi",
        "cond-1pl-neg": "1kisi",
        "cond-2pl-neg": "1kisi",
        "cond-3pl-neg": "1kisi",
        "cond-pass-neg": "1ht2isi",
        "impr-2sg": "1e",
        "impr-3sg": "1hk2-OOn",
        "impr-1pl": "1hk22mme",
        "impr-2pl": "1hk22",
        "impr-3pl": "1hk2-OOt",
        "impr-pass": "1ht2kOOn",
        "impr-2sg-neg": "1e",
        "impr-3sg-neg": "1hk2-O",
        "impr-1pl-neg": "1hk2-O",
        "impr-2pl-neg": "1hk2-O",
        "impr-3pl-neg": "1hk2-O",
        "impr-pass-neg": "1ht2kO",
        "potn-1sg": "1hnen",
        "potn-2sg": "1hnet",
        "potn-3sg": "1hnee",
        "potn-1pl": "1hnemme",
        "potn-2pl": "1hnette",
        "potn-3pl": "1hnev2t",
        "potn-pass": "1ht2neen",
        "potn-1sg-neg": "1hne",
        "potn-2sg-neg": "1hne",
        "potn-3sg-neg": "1hne",
        "potn-1pl-neg": "1hne",
        "potn-2pl-neg": "1hne",
        "potn-3pl-neg": "1hne",
        "potn-pass-neg": "1ht2ne",
        "pres-part": "1kev2",
        "pres-pass-part": "1ht2v2",
        "past-part": "1hn2-Ut",
        "past-pass-part": "1ht2-U",
        "agnt-part": "1kem2",
        "nega-part": "1kem2tOn",
        "inf1": "1hd2",
        "inf1-long": "1hd2kse",  # +poss_suff
        "inf2-ine": "1hdess2",
        "inf2-pass-ine": "1ht2ess2",
        "inf2-ins": "1hden",
        "inf3-ine": "1kem2ss2",
        "inf3-ela": "1kem2st2",
        "inf3-ill": "1kem22n",
        "inf3-ade": "1kem2ll2",
        "inf3-abe": "1kem2tt2",
        "inf3-ins": "1kem2n",
        "inf3-pass-ins": "1ht2m2n",
        "inf4-nom": "1keminen",
        "inf4-nom-poss": "1kemise",
        "inf4-par": "1kemist2",
        "inf5": "1kem2isill2",  # +poss_suff
    },
    "fi-conj-vanheta": {
    	"nargs": 5,
        "pres-1sg": "134nen",
        "pres-2sg": "134net",
        "pres-3sg": "134nee",
        "pres-1pl": "134nemme",
        "pres-2pl": "134nette",
        "pres-3pl": "134nev5t",
        "pres-pass": "124t55n",
        "pres-1sg-neg": "134ne",
        "pres-2sg-neg": "134ne",
        "pres-3sg-neg": "134ne",
        "pres-1pl-neg": "134ne",
        "pres-2pl-neg": "134ne",
        "pres-3pl-neg": "134ne",
        "pres-pass-neg": "124t5",
        "past-1sg": "134nin",
        "past-2sg": "134nit",
        "past-3sg": "134ni",
        "past-1pl": "134nimme",
        "past-2pl": "134nitte",
        "past-3pl": "134niv5t",
        "past-pass": "124ttiin",
        "past-1sg-neg": "124nn5-Ut",
        "past-2sg-neg": "124nn5-Ut",
        "past-3sg-neg": "124nn5-Ut",
        "past-1pl-neg": "124nneet",
        "past-2pl-neg": "124nneet",
        "past-3pl-neg": "124nneet",
        "past-pass-neg": "124tt5-U",
        "cond-1sg": "134nisin",
        "cond-2sg": "134nisit",
        "cond-3sg": "134nisi",
        "cond-1pl": "134nisimme",
        "cond-2pl": "134nisitte",
        "cond-3pl": "134nisiv5t",
        "cond-pass": "124tt5isiin",
        "cond-1sg-neg": "134nisi",
        "cond-2sg-neg": "134nisi",
        "cond-3sg-neg": "134nisi",
        "cond-1pl-neg": "134nisi",
        "cond-2pl-neg": "134nisi",
        "cond-3pl-neg": "134nisi",
        "cond-pass-neg": "124tt5isi",
        "impr-2sg": "134ne",
        "impr-3sg": "124tk5-OOn",
        "impr-1pl": "124tk55mme",
        "impr-2pl": "124tk55",
        "impr-3pl": "124tk5-OOt",
        "impr-pass": "124tt5kOOn",
        "impr-2sg-neg": "134ne",
        "impr-3sg-neg": "124tk5-O",
        "impr-1pl-neg": "124tk5-O",
        "impr-2pl-neg": "124tk5-O",
        "impr-3pl-neg": "124tk5-O",
        "impr-pass-neg": "124tt5kO",
        "potn-1sg": "124nnen",
        "potn-2sg": "124nnet",
        "potn-3sg": "124nnee",
        "potn-1pl": "124nnemme",
        "potn-2pl": "124nnette",
        "potn-3pl": "124nnev5t",
        "potn-pass": "124tt5neen",
        "potn-1sg-neg": "124nne",
        "potn-2sg-neg": "124nne",
        "potn-3sg-neg": "124nne",
        "potn-1pl-neg": "124nne",
        "potn-2pl-neg": "124nne",
        "potn-3pl-neg": "124nne",
        "potn-pass-neg": "124tt5ne",
        "pres-part": "134nev5",
        "pres-pass-part": "124tt5v5",
        "past-part": "124nn5-Ut",
        "past-pass-part": "124tt5-U",
        "agnt-part": "134nem5",
        "nega-part": "134nem5tOn",
        "inf1": "124t5",
        "inf1-long": "124t5kse",  # +poss_suff
        "inf2-ine": "124tess5",
        "inf2-pass-ine": "124tt5ess5",
        "inf2-ins": "124ten",
        "inf3-ine": "134nem5ss5",
        "inf3-ela": "134nem5st5",
        "inf3-ill": "134nem55n",
        "inf3-ade": "134nem5ll5",
        "inf3-abe": "134nem5tt5",
        "inf3-ins": "134nem5n",
        "inf3-pass-ins": "124tt5m5n",
        "inf4-nom": "134neminen",
        "inf4-nom-poss": "134nemise",
        "inf4-par": "134nemist5",
        "inf5": "134nem5isill5",  # +poss_suff
    },
    "fi-conj-salata": {
    	"nargs": 4,
        "pres-1sg": "1344n",
        "pres-2sg": "1344t",
        "pres-3sg": "1344",
        "pres-1pl": "1344mme",
        "pres-2pl": "1344tte",
        "pres-3pl": "1344v4t",
        "pres-pass": "124t44n",
        "pres-1sg-neg": "1344",
        "pres-2sg-neg": "1344",
        "pres-3sg-neg": "1344",
        "pres-1pl-neg": "1344",
        "pres-2pl-neg": "1344",
        "pres-3pl-neg": "1344",
        "pres-pass-neg": "124t4",
        "past-1sg": "134sin",
        "past-2sg": "134sit",
        "past-3sg": "134si",
        "past-1pl": "134simme",
        "past-2pl": "134sitte",
        "past-3pl": "134siv4t",
        "past-pass": "124ttiin",
        "past-1sg-neg": "124nnUt",
        "past-2sg-neg": "124nnUt",
        "past-3sg-neg": "124nnUt",
        "past-1pl-neg": "124nneet",
        "past-2pl-neg": "124nneet",
        "past-3pl-neg": "124nneet",
        "past-pass-neg": "124tt4-U",
        "cond-1sg": "134isin",
        "cond-2sg": "134isit",
        "cond-3sg": "134isi",
        "cond-1pl": "134isimme",
        "cond-2pl": "134isitte",
        "cond-3pl": "134isiv4t",
        "cond-pass": "124tt4isiin",
        "cond-1sg-neg": "134isi",
        "cond-2sg-neg": "134isi",
        "cond-3sg-neg": "134isi",
        "cond-1pl-neg": "134isi",
        "cond-2pl-neg": "134isi",
        "cond-3pl-neg": "134isi",
        "cond-pass-neg": "124tt4isi",
        "impr-2sg": "1344",
        "impr-3sg": "124tkOOn",
        "impr-1pl": "124tk44mme",
        "impr-2pl": "124tk44",
        "impr-3pl": "124tkOOt",
        "impr-pass": "124tt4kOOn",
        "impr-2sg-neg": "1344",
        "impr-3sg-neg": "124tkO",
        "impr-1pl-neg": "124tkO",
        "impr-2pl-neg": "124tkO",
        "impr-3pl-neg": "124tkO",
        "impr-pass-neg": "124tt4kO",
        "potn-1sg": "124nnen",
        "potn-2sg": "124nnet",
        "potn-3sg": "124nnee",
        "potn-1pl": "124nnemme",
        "potn-2pl": "124nnette",
        "potn-3pl": "124nnev4t",
        "potn-pass": "124tt4neen",
        "potn-1sg-neg": "124nne",
        "potn-2sg-neg": "124nne",
        "potn-3sg-neg": "124nne",
        "potn-1pl-neg": "124nne",
        "potn-2pl-neg": "124nne",
        "potn-3pl-neg": "124nne",
        "potn-pass-neg": "124tt4ne",
        "pres-part": "1344v4",
        "pres-pass-part": "124tt4v4",
        "past-part": "124nnUt",
        "past-pass-part": "124ttU",
        "agnt-part": "1344m4",
        "nega-part": "1344m4tOn",
        "inf1": "124t4",
        "inf1-long": "124t4kse",  # +poss_suff
        "inf2-ine": "124tess4",
        "inf2-pass-ine": "124tt4ess4",
        "inf2-ins": "124ten",
        "inf3-ine": "1344m4ss4",
        "inf3-ela": "1344m4st4",
        "inf3-ill": "1344m44n",
        "inf3-ade": "1344m4ll4",
        "inf3-abe": "1344m4tt4",
        "inf3-ins": "1344m4n",
        "inf3-pass-ins": "124tt4m4n",
        "inf4-nom": "1344minen",
        "inf4-nom-poss": "1344mise",
        "inf4-par": "1344mist4",
        "inf5": "1344m4isill4",  # +poss_suff
    },
    "fi-conj-katketa": {
    	"nargs": 5,
        "pres-1sg": "1345n",
        "pres-2sg": "1345t",
        "pres-3sg": "13455",
        "pres-1pl": "1345mme",
        "pres-2pl": "1345tte",
        "pres-3pl": "1345v5t",
        "pres-pass": "124t55n",
        "pres-1sg-neg": "1345",
        "pres-2sg-neg": "1345",
        "pres-3sg-neg": "1345",
        "pres-1pl-neg": "1345",
        "pres-2pl-neg": "1345",
        "pres-3pl-neg": "1345",
        "pres-pass-neg": "124t5",
        "past-1sg": "134sin",
        "past-2sg": "134sit",
        "past-3sg": "134si",
        "past-1pl": "134simme",
        "past-2pl": "134sitte",
        "past-3pl": "134siv5t",
        "past-pass": "124ttiin",
        "past-1sg-neg": "124nn5-Ut",
        "past-2sg-neg": "124nn5-Ut",
        "past-3sg-neg": "124nn5-Ut",
        "past-1pl-neg": "124nneet",
        "past-2pl-neg": "124nneet",
        "past-3pl-neg": "124nneet",
        "past-pass-neg": "124tt5-U",
        "cond-1sg": ["1345isin", "134isin"],
        "cond-2sg": ["1345isit", "134isit"],
        "cond-3sg": ["1345isi", "134isi"],
        "cond-1pl": ["1345isimme", "134isimme"],
        "cond-2pl": ["1345isitte", "134isitte"],
        "cond-3pl": ["1345isiv5t", "134isiv5t"],
        "cond-pass": "124tt5isiin",
        "cond-1sg-neg": ["1345isi", "134isi"],
        "cond-2sg-neg": ["1345isi", "134isi"],
        "cond-3sg-neg": ["1345isi", "134isi"],
        "cond-1pl-neg": ["1345isi", "134isi"],
        "cond-2pl-neg": ["1345isi", "134isi"],
        "cond-3pl-neg": ["1345isi", "134isi"],
        "cond-pass-neg": "124tt5isi",
        "impr-2sg": "1345",
        "impr-3sg": "124tk5-OOn",
        "impr-1pl": "124tk55mme",
        "impr-2pl": "124tk55",
        "impr-3pl": "124tk5-OOt",
        "impr-pass": "124tt5kOOn",
        "impr-2sg-neg": "1345",
        "impr-3sg-neg": "124tk5-O",
        "impr-1pl-neg": "124tk5-O",
        "impr-2pl-neg": "124tk5-O",
        "impr-3pl-neg": "124tk5-O",
        "impr-pass-neg": "124tt5kO",
        "potn-1sg": "124nnen",
        "potn-2sg": "124nnet",
        "potn-3sg": "124nnee",
        "potn-1pl": "124nnemme",
        "potn-2pl": "124nnette",
        "potn-3pl": "124nnev5t",
        "potn-pass": "124tt5neen",
        "potn-1sg-neg": "124nne",
        "potn-2sg-neg": "124nne",
        "potn-3sg-neg": "124nne",
        "potn-1pl-neg": "124nne",
        "potn-2pl-neg": "124nne",
        "potn-3pl-neg": "124nne",
        "potn-pass-neg": "124tt5ne",
        "pres-part": "1345v5",
        "pres-pass-part": "124tt5v5",
        "past-part": "124nn5-Ut",
        "past-pass-part": "124tt5-U",
        "agnt-part": "1345m5",
        "nega-part": "1345m5tOn",
        "inf1": "124t5",
        "inf1-long": "124t5kse",  # +poss_suff
        "inf2-ine": "124tess5",
        "inf2-pass-ine": "124tt5ess5",
        "inf2-ins": "124ten",
        "inf3-ine": "1345m5ss5",
        "inf3-ela": "1345m5st5",
        "inf3-ill": "1345m55n",
        "inf3-ade": "1345m5ll5",
        "inf3-abe": "1345m5tt5",
        "inf3-ins": "1345m5n",
        "inf3-pass-ins": "124tt5m5n",
        "inf4-nom": "1345minen",
        "inf4-nom-poss": "1345mise",
        "inf4-par": "1345mist5",
        "inf5": "1345m5isill5",  # +poss_suff
    },
    "fi-conj-selvitä": {
    	"nargs": 5,
        "pres-1sg": "1345n",
        "pres-2sg": "1345t",
        "pres-3sg": "13455",
        "pres-1pl": "1345mme",
        "pres-2pl": "1345tte",
        "pres-3pl": "1345v5t",
        "pres-pass": "124t55n",
        "pres-1sg-neg": "1345",
        "pres-2sg-neg": "1345",
        "pres-3sg-neg": "1345",
        "pres-1pl-neg": "1345",
        "pres-2pl-neg": "1345",
        "pres-3pl-neg": "1345",
        "pres-pass-neg": "124t5",
        "past-1sg": "134sin",
        "past-2sg": "134sit",
        "past-3sg": "134si",
        "past-1pl": "134simme",
        "past-2pl": "134sitte",
        "past-3pl": "134siv5t",
        "past-pass": "124ttiin",
        "past-1sg-neg": "124nn5-Ut",
        "past-2sg-neg": "124nn5-Ut",
        "past-3sg-neg": "124nn5-Ut",
        "past-1pl-neg": "124nneet",
        "past-2pl-neg": "124nneet",
        "past-3pl-neg": "124nneet",
        "past-pass-neg": "124tt5-U",
        "cond-1sg": ["1345isin"],
        "cond-2sg": ["1345isit"],
        "cond-3sg": ["1345isi"],
        "cond-1pl": ["1345isimme"],
        "cond-2pl": ["1345isitte"],
        "cond-3pl": ["1345isiv5t"],
        "cond-pass": "124tt5isiin",
        "cond-1sg-neg": ["1345isi"],
        "cond-2sg-neg": ["1345isi"],
        "cond-3sg-neg": ["1345isi"],
        "cond-1pl-neg": ["1345isi"],
        "cond-2pl-neg": ["1345isi"],
        "cond-3pl-neg": ["1345isi"],
        "cond-pass-neg": "124tt5isi",
        "impr-2sg": "1345",
        "impr-3sg": "124tk5-OOn",
        "impr-1pl": "124tk55mme",
        "impr-2pl": "124tk55",
        "impr-3pl": "124tk5-OOt",
        "impr-pass": "124tt5kOOn",
        "impr-2sg-neg": "1345",
        "impr-3sg-neg": "124tk5-O",
        "impr-1pl-neg": "124tk5-O",
        "impr-2pl-neg": "124tk5-O",
        "impr-3pl-neg": "124tk5-O",
        "impr-pass-neg": "124tt5kO",
        "potn-1sg": "124nnen",
        "potn-2sg": "124nnet",
        "potn-3sg": "124nnee",
        "potn-1pl": "124nnemme",
        "potn-2pl": "124nnette",
        "potn-3pl": "124nnev5t",
        "potn-pass": "124tt5neen",
        "potn-1sg-neg": "124nne",
        "potn-2sg-neg": "124nne",
        "potn-3sg-neg": "124nne",
        "potn-1pl-neg": "124nne",
        "potn-2pl-neg": "124nne",
        "potn-3pl-neg": "124nne",
        "potn-pass-neg": "124tt5ne",
        "pres-part": "1345v5",
        "pres-pass-part": "124tt5v5",
        "past-part": "124nn5-Ut",
        "past-pass-part": "124tt5-U",
        "agnt-part": "1345m5",
        "nega-part": "1345m5tOn",
        "inf1": "124t5",
        "inf1-long": "124t5kse",  # +poss_suff
        "inf2-ine": "124tess5",
        "inf2-pass-ine": "124tt5ess5",
        "inf2-ins": "124ten",
        "inf3-ine": "1345m5ss5",
        "inf3-ela": "1345m5st5",
        "inf3-ill": "1345m55n",
        "inf3-ade": "1345m5ll5",
        "inf3-abe": "1345m5tt5",
        "inf3-ins": "1345m5n",
        "inf3-pass-ins": "124tt5m5n",
        "inf4-nom": "1345minen",
        "inf4-nom-poss": "1345mise",
        "inf4-par": "1345mist5",
        "inf5": "1345m5isill5",  # +poss_suff
    },
    "fi-conj-taitaa": {
    	"nargs": 2,
        "pres-1sg": "1D2n",
        "pres-2sg": "1D2t",
        "pres-3sg": "1t22",
        "pres-1pl": "1D2mme",
        "pres-2pl": "1D2tte",
        "pres-3pl": "1t2v2t",
        "pres-pass": "1Det22n",
        "pres-1sg-neg": "1D2",
        "pres-2sg-neg": "1D2",
        "pres-3sg-neg": "1D2",
        "pres-1pl-neg": "1D2",
        "pres-2pl-neg": "1D2",
        "pres-3pl-neg": "1D2",
        "pres-pass-neg": "1Det2",
        "past-1sg": ["1sin"],
        "past-2sg": ["1sit"],
        "past-3sg": ["1si"],
        "past-1pl": ["1simme"],
        "past-2pl": ["1sitte"],
        "past-3pl": ["1siv2t"],
        "past-pass": "1Dettiin",
        "past-1sg-neg": ["1t2nUt", "1nn2-Ut"],
        "past-2sg-neg": ["1t2nUt", "1nn2-Ut"],
        "past-3sg-neg": ["1t2nUt", "1nn2-Ut"],
        "past-1pl-neg": ["1t2neet", "1nneet"],
        "past-2pl-neg": ["1t2neet", "1nneet"],
        "past-3pl-neg": ["1t2neet", "1nneet"],
        "past-pass-neg": "1Dett2-U",
        "cond-1sg": "1t2isin",
        "cond-2sg": "1t2isit",
        "cond-3sg": "1t2isi",
        "cond-1pl": "1t2isimme",
        "cond-2pl": "1t2isitte",
        "cond-3pl": "1t2isiv2t",
        "cond-pass": "1Dett2isiin",
        "cond-1sg-neg": "1t2isi",
        "cond-2sg-neg": "1t2isi",
        "cond-3sg-neg": "1t2isi",
        "cond-1pl-neg": "1t2isi",
        "cond-2pl-neg": "1t2isi",
        "cond-3pl-neg": "1t2isi",
        "cond-pass-neg": "1Dett2isi",
        "impr-2sg": "1D2",
        "impr-3sg": "1t2kOOn",
        "impr-1pl": "1t2k22mme",
        "impr-2pl": "1t2k22",
        "impr-3pl": "1t2kOOt",
        "impr-pass": "1Dett2kOOn",
        "impr-2sg-neg": "1D2",
        "impr-3sg-neg": "1t2kO",
        "impr-1pl-neg": "1t2kO",
        "impr-2pl-neg": "1t2kO",
        "impr-3pl-neg": "1t2kO",
        "impr-pass-neg": "1Dett2kO",
        "potn-1sg": ["1t2nen", "1nnen"],
        "potn-2sg": ["1t2net", "1nnet"],
        "potn-3sg": ["1t2nee", "1nnee"],
        "potn-1pl": ["1t2nemme", "1nnemme"],
        "potn-2pl": ["1t2nette", "1nnette"],
        "potn-3pl": ["1t2nev2t", "1nnev2t"],
        "potn-pass": "1Dett2neen",
        "potn-1sg-neg": ["1t2ne", "1nne"],
        "potn-2sg-neg": ["1t2ne", "1nne"],
        "potn-3sg-neg": ["1t2ne", "1nne"],
        "potn-1pl-neg": ["1t2ne", "1nne"],
        "potn-2pl-neg": ["1t2ne", "1nne"],
        "potn-3pl-neg": ["1t2ne", "1nne"],
        "potn-pass-neg": "1Dett2ne",
        "pres-part": "1t2v2",
        "pres-pass-part": "1Dett2v2",
        "past-part": ["1t2nUt", "1nnUt"],
        "past-pass-part": "1Dett2-U",
        "agnt-part": "1t2m2",
        "nega-part": "1t2m2tOn",
        "inf1": "1t22",
        "inf1-long": "1t22kse",  # +poss_suff
        "inf2-ine": "1t2ess2",
        "inf2-pass-ine": "1Dett2ess2",
        "inf2-ins": "1t2en",
        "inf3-ine": "1t2m2ss2",
        "inf3-ela": "1t2m2st2",
        "inf3-ill": "1t2m22n",
        "inf3-ade": "1t2m2ll2",
        "inf3-abe": "1t2m2tt2",
        "inf3-ins": "1t2m2n",
        "inf3-pass-ins": "1Dett2m2n",
        "inf4-nom": "1t2minen",
        "inf4-nom-poss": "1t2mise",
        "inf4-par": "1t2mist2",
        "inf5": "1t2m2isill2",  # +poss_suff
    },
    "fi-conj-kaikaa": {
        # This is a degenerative conjugation for certain verbs that are
	# practically only used in 3rd person indicative (and possibly
	# conditional).  These are mostly poetic/archaic.
    	"nargs": 2,
	"pres-3sg": "122",
	"pres-3pl": "122v2t",
	"pres-3sg-neg": "122",
	"pres-3pl-neg": "122",
	"cond-3sg": "12isi",
	"cond-3pl": "12isiv2t",
	"cond-3sg-neg": "12isi",
	"cond-3pl-neg": "12isi",
	"inf1": "122",
    },
    "fi-conj-kumajaa": {
    	"nargs": 2,
	"ignore-extra-args": True,
        "pres-1sg": "12j2n",
        "pres-2sg": "12j2t",
        "pres-3sg": "12j22",
        "pres-1pl": "12j2mme",
        "pres-2pl": "12j2tte",
        "pres-3pl": "12j2v2t",
        "pres-pass": "12j2t22n",
        "pres-1sg-neg": "12j2",
        "pres-2sg-neg": "12j2",
        "pres-3sg-neg": "12j2",
        "pres-1pl-neg": "12j2",
        "pres-2pl-neg": "12j2",
        "pres-3pl-neg": "12j2",
        "pres-pass-neg": "12j2t2",
        "past-1sg": "12jin",
        "past-2sg": "12jit",
        "past-3sg": "12ji",
        "past-1pl": "12jimme",
        "past-2pl": "12jitte",
        "past-3pl": "12jivat",
        "past-pass": "12j2ttiin",
        "past-1sg-neg": "12j2nUt",
        "past-2sg-neg": "12j2nUt",
        "past-3sg-neg": "12j2nUt",
        "past-1pl-neg": "12j2neet",
        "past-2pl-neg": "12j2neet",
        "past-3pl-neg": "12j2neet",
        "past-pass-neg": "12j2ttU",
        "cond-1sg": "12j2isin",
        "cond-2sg": "12j2isit",
        "cond-3sg": "12j2isi",
        "cond-1pl": "12j2isimme",
        "cond-2pl": "12j2isitte",
        "cond-3pl": "12j2isiv2t",
        "cond-pass": "12j2tt2isiin",
        "cond-1sg-neg": "12j2isi",
        "cond-2sg-neg": "12j2isi",
        "cond-3sg-neg": "12j2isi",
        "cond-1pl-neg": "12j2isi",
        "cond-2pl-neg": "12j2isi",
        "cond-3pl-neg": "12j2isi",
        "cond-pass-neg": "12j2tt2isi",
        "impr-2sg": "12j2",
        "impr-3sg": "12j2kOOn",
        "impr-1pl": "12j2k22mme",
        "impr-2pl": "12j2k22",
        "impr-3pl": "12j2kOOt",
        "impr-pass": "12j2tt2kOOn",
        "impr-2sg-neg": "12j2",
        "impr-3sg-neg": "12j2kO",
        "impr-1pl-neg": "12j2kO",
        "impr-2pl-neg": "12j2kO",
        "impr-3pl-neg": "12j2kO",
        "impr-pass-neg": "12j2tt2kO",
        "potn-1sg": "12j2nen",
        "potn-2sg": "12j2net",
        "potn-3sg": "12j2nee",
        "potn-1pl": "12j2nemme",
        "potn-2pl": "12j2nette",
        "potn-3pl": "12j2nev2t",
        "potn-pass": "12j2tt2kOOn",
        "potn-1sg-neg": "12j2ne",
        "potn-2sg-neg": "12j2n2",
        "potn-3sg-neg": "12j2ne",
        "potn-1pl-neg": "12j2ne",
        "potn-2pl-neg": "12j2ne",
        "potn-3pl-neg": "12j2ne",
        "potn-pass-neg": "12j2tt2ne",
        "pres-part": "12j2v2",
        "pres-pass-part": "12j2tt2v2",
        "past-part": "12j2nUt",
        "past-pass-part": "12j2ttU",
        "agnt-part": "12j2m2",
        "nega-part": "12j2m2tOn",
        "inf1": "12j22",
        "inf1-long": "12j22kse",  # +poss_suff
        "inf2-ine": "12j2ess2",
        "inf2-pass-ine": "12j2tt2ess2",
        "inf2-ins": "12j2en",
        "inf3-ine": "12j2m2ss2",
        "inf3-ela": "12j2m2st2",
        "inf3-ill": "12j2m22n",
        "inf3-ade": "12j2m2ll2",
        "inf3-abe": "12j2m2tt2",
        "inf3-ins": "12j2m2n",
        "inf3-pass-ins": "12j2tt2m2n",
        "inf4-nom": "12j2minen",
        "inf4-nom-poss": "12j2mise",
        "inf4-par": "12j2mist2",
        "inf5": "12j2m2isill2",  # +poss_suff
    },
    "fi-conj-olla": {
    	"nargs": 0,
        "pres-1sg": "olen",
        "pres-2sg": "olet",
        "pres-3sg": "on",
        "pres-1pl": "olemme",
        "pres-2pl": "olette",
        "pres-3pl": "ovat",
        "pres-pass": "ollaan",
        "pres-1sg-neg": "ole",
        "pres-2sg-neg": "ole",
        "pres-3sg-neg": "ole",
        "pres-1pl-neg": "olleet",
        "pres-2pl-neg": "olleet",
        "pres-3pl-neg": "olleet",
        "pres-pass-neg": "oltu",
        "past-1sg": "olin",
        "past-2sg": "olit",
        "past-3sg": "oli",
        "past-1pl": "olimme",
        "past-2pl": "olitte",
        "past-3pl": "olivat",
        "past-pass": "oltiin",
        "past-1sg-neg": "ollut",
        "past-2sg-neg": "ollut",
        "past-3sg-neg": "ollut",
        "past-1pl-neg": "olleet",
        "past-2pl-neg": "olleet",
        "past-3pl-neg": "olleet",
        "past-pass-neg": "oltu",
        "cond-1sg": "olisin",
        "cond-2sg": "olisit",
        "cond-3sg": "olisi",
        "cond-1pl": "olisimme",
        "cond-2pl": "olisitte",
        "cond-3pl": "olisivat",
        "cond-pass": "oltaisiin",
        "cond-1sg-neg": "olisi",
        "cond-2sg-neg": "olisi",
        "cond-3sg-neg": "olisi",
        "cond-1pl-neg": "olisi",
        "cond-2pl-neg": "olisi",
        "cond-3pl-neg": "olisi",
        "cond-pass-neg": "oltaisi",
        "impr-2sg": "ole",
        "impr-3sg": "olkoon",
        "impr-1pl": "olkaamme",
        "impr-2pl": "olkaa",
        "impr-3pl": "olkoot",
        "impr-pass": "oltakoon",
        "impr-2sg-neg": "ole",
        "impr-3sg-neg": "olko",
        "impr-1pl-neg": "olko",
        "impr-2pl-neg": "olko",
        "impr-3pl-neg": "olko",
        "impr-pass-neg": "oltako",
        "potn-1sg": "lienen",
        "potn-2sg": "lienet",
        "potn-3sg": "lienee",
        "potn-1pl": "lienemme",
        "potn-2pl": "lienette",
        "potn-3pl": "lienevät",
        "potn-pass": "oltaneen",
        "potn-1sg-neg": "liene",
        "potn-2sg-neg": "liene",
        "potn-3sg-neg": "liene",
        "potn-1pl-neg": "liene",
        "potn-2pl-neg": "liene",
        "potn-3pl-neg": "liene",
        "potn-pass-neg": "oltane",
        "pres-part": "oleva",
        "pres-pass-part": "oltava",
        "past-part": "ollut",
        "past-pass-part": "oltu",
        "agnt-part": "olema",
        "nega-part": "olematon",
        "inf1": "olla",
        "inf1-long": "ollakse",  # +poss_suff
        "inf2-ine": "ollessa",
        "inf2-pass-ine": "oltaessa",
        "inf2-ins": "ollen",
        "inf3-ine": "olemassa",
        "inf3-ela": "olemasta",
        "inf3-ill": "olemaan",
        "inf3-ade": "olemalla",
        "inf3-abe": "olematta",
        "inf3-ins": "oleman",
        "inf3-pass-ins": "oltaman",
        "inf4-nom": "oleminen",
        "inf4-nom-poss": "olemise",
        "inf4-par": "olemista",
        "inf5": "olemaisilla",  # +poss_suff
    },
    "fi-conj-ei": {
    	"nargs": 0,
        "pres-1sg": "en",
	"pres-2sg": "et",
	"pres-3sg": "ei",
	"pres-1pl": "emme",
	"pres-2pl": "ette",
	"pres-3pl": "eivät",
	"impt-1sg": ["älkääni", "älkäämi", "ällön"],  # Not currently used
	"impr-2sg": ["älä", "ällös"],  # Latter really optative
	"impr-3sg": ["älköön", "älkööt"],
	"impr-1pl": ["älkäämme", "älköömme"],
	"impr-2pl": ["älkää", "älköötte"],
	"impr-3pl": ["älkööt", "älkööt"],
    },

    "fi-conj-seistä": {
    	"nargs": 0,
        "pres-1sg": "seison",
        "pres-2sg": "seisot",
        "pres-3sg": "seisoo",
        "pres-1pl": "seisomme",
        "pres-2pl": "seisotte",
        "pres-3pl": "seisovat",
        "pres-pass": "seistään",
        "pres-1sg-neg": "seiso",
        "pres-2sg-neg": "seiso",
        "pres-3sg-neg": "seiso",
        "pres-1pl-neg": "seiso",
        "pres-2pl-neg": "seiso",
        "pres-3pl-neg": "seiso",
        "pres-pass-neg": "seistä",
        "past-1sg": "seisoin",
        "past-2sg": "seisoit",
        "past-3sg": "seisoi",
        "past-1pl": "seisoimme",
        "past-2pl": "seisoitte",
        "past-3pl": "seisoivat",
        "past-pass": "seistiin",
        "past-1sg-neg": "seissyt",
        "past-2sg-neg": "seissyt",
        "past-3sg-neg": "seissyt",
        "past-1pl-neg": "seisseet",
        "past-2pl-neg": "seisseet",
        "past-3pl-neg": "seisseet",
        "past-pass-neg": "seisty",
        "cond-1sg": "seisoisin",
        "cond-2sg": "seisoisit",
        "cond-3sg": "seisoisi",
        "cond-1pl": "seisoisimme",
        "cond-2pl": "seisoisitte",
        "cond-3pl": "seisoisivat",
        "cond-pass": "seistäisiin",
        "cond-1sg-neg": "seisoisi",
        "cond-2sg-neg": "seisoisi",
        "cond-3sg-neg": "seisoisi",
        "cond-1pl-neg": "seisoisi",
        "cond-2pl-neg": "seisoisi",
        "cond-3pl-neg": "seisoisi",
        "cond-pass-neg": "seistäisi",
        "impr-2sg": "seiso",
        "impr-3sg": "seisköön",
        "impr-1pl": "seiskäämme",
        "impr-2pl": "seiskää",
        "impr-3pl": "seiskööt",
        "impr-pass": "seistäköön",
        "impr-2sg-neg": "seiso",
        "impr-3sg-neg": "seiskö",
        "impr-1pl-neg": "seiskö",
        "impr-2pl-neg": "seiskö",
        "impr-3pl-neg": "seiskö",
        "impr-pass-neg": "seistäkö",
        "potn-1sg": "seissen",
        "potn-2sg": "seisset",
        "potn-3sg": "seissee",
        "potn-1pl": "seissemme",
        "potn-2pl": "seissette",
        "potn-3pl": "seissevät",
        "potn-pass": "seistäneen",
        "potn-1sg-neg": "seisse",
        "potn-2sg-neg": "seisse",
        "potn-3sg-neg": "seisse",
        "potn-1pl-neg": "seisse",
        "potn-2pl-neg": "seisse",
        "potn-3pl-neg": "seisse",
        "potn-pass-neg": "seistäne",
        "pres-part": "seisova",
        "pres-pass-part": "seistävä",
        "past-part": "seissyt",
        "past-pass-part": "seisty",
        "agnt-part": "seisoma",
        "nega-part": "seisomaton",
        "inf1": "seistä",
        "inf1-long": "seistäkse",  # +poss_suff
        "inf2-ine": "seistessä",
        "inf2-pass-ine": "seistäessä",
        "inf2-ins": "seisten",
        "inf3-ine": "seisomassa",
        "inf3-ela": "seisomasta",
        "inf3-ill": "seisomaan",
        "inf3-ade": "seisomalla",
        "inf3-abe": "seisomatta",
        "inf3-ins": "seisoman",
        "inf3-pass-ins": "seistämän",
        "inf4-nom": "seisominen",
        "inf4-nom-poss": "seisomise",
        "inf4-par": "seisomista",
        "inf5": "seisomaisilla",  # +poss_suff
    },

    "fi-conj-virkkaa": {
    	"nargs": 0,
        "pres-1sg": "virkan",
        "pres-2sg": "virkat",
        "pres-3sg": "virkkaa",
        "pres-1pl": "virkamme",
        "pres-2pl": "virkatte",
        "pres-3pl": "virkkavat",
        "pres-pass": "virketään",
        "pres-1sg-neg": "virka",
        "pres-2sg-neg": "virka",
        "pres-3sg-neg": "virka",
        "pres-1pl-neg": "virka",
        "pres-2pl-neg": "virka",
        "pres-3pl-neg": "virka",
        "pres-pass-neg": "virketä",
        "past-1sg": "virkoin",
        "past-2sg": "virkoit",
        "past-3sg": "virkkoi",
        "past-1pl": "virkoimme",
        "past-2pl": "virkoitte",
        "past-3pl": "virkkoivat",
        "past-pass": "virkettiin",
        "past-1sg-neg": "virkkanut",
        "past-2sg-neg": "virkkanut",
        "past-3sg-neg": "virkkanut",
        "past-1pl-neg": "virkkaneet",
        "past-2pl-neg": "virkkaneet",
        "past-3pl-neg": "virkkaneet",
        "past-pass-neg": "virketty",
        "cond-1sg": "virkkaisin",
        "cond-2sg": "virkkaisit",
        "cond-3sg": "virkkaisi",
        "cond-1pl": "virkkaisimme",
        "cond-2pl": "virkkaisitte",
        "cond-3pl": "virkkaisivat",
        "cond-pass": "virkettäisiin",
        "cond-1sg-neg": "virkkaisi",
        "cond-2sg-neg": "virkkaisi",
        "cond-3sg-neg": "virkkaisi",
        "cond-1pl-neg": "virkkaisi",
        "cond-2pl-neg": "virkkaisi",
        "cond-3pl-neg": "virkkaisi",
        "cond-pass-neg": "virkettäisi",
        "impr-2sg": "virka",
        "impr-3sg": "virkkakoon",
        "impr-1pl": "virkkakaamme",
        "impr-2pl": "virkkakaa",
        "impr-3pl": "virkkakoot",
        "impr-pass": "virkettäköön",
        "impr-2sg-neg": "virka",
        "impr-3sg-neg": "virkkako",
        "impr-1pl-neg": "virkkako",
        "impr-2pl-neg": "virkkako",
        "impr-3pl-neg": "virkkako",
        "impr-pass-neg": "virkettäkö",
        "potn-1sg": "virkkanen",
        "potn-2sg": "virkkanet",
        "potn-3sg": "virkkanee",
        "potn-1pl": "virkkanemme",
        "potn-2pl": "virkkanette",
        "potn-3pl": "virkkanevat",
        "potn-pass": "virkettäneen",
        "potn-1sg-neg": "virkkane",
        "potn-2sg-neg": "virkkane",
        "potn-3sg-neg": "virkkane",
        "potn-1pl-neg": "virkkane",
        "potn-2pl-neg": "virkkane",
        "potn-3pl-neg": "virkkane",
        "potn-pass-neg": "virkettäne",
        "pres-part": "virkkava",
        "pres-pass-part": "virkettävä",
        "past-part": "virkkanut",
        "past-pass-part": "virketty",
        "agnt-part": "virkkama",
        "nega-part": "virkkamaton",
        "inf1": "virkkaa",
        "inf1-long": "virkkaessa",  # +poss_suff
        "inf2-ine": "virkkaessa",
        "inf2-pass-ine": "virkkamassa",
        "inf2-ins": "virkkaen",
        "inf3-ine": "virkkamassa",
        "inf3-ela": "virkkamasta",
        "inf3-ill": "virkkamaan",
        "inf3-ade": "virkkamalla",
        "inf3-abe": "virkkamatta",
        "inf3-ins": "virkkaman",
        "inf3-pass-ins": "virkettämän",
        "inf4-nom": "virkkaminen",
        "inf4-nom-poss": "virkkamise",
        "inf4-par": "virkkamista",
        "inf5": "virkkamaisilla",  # +poss_suff
    },

    "fi-conj-table": {
        # This is intentionally empty.  This conjunction is used for irrregular
	# verbs, and all forms are listed as arguments, as exceptions.
    },

    "fi-conj": {
        # This is intentionally empty.  This conjugation is used for irregular
	# verbs, and all forms are listed as arguments, as exceptions.
	# Note that this uses different argument names than fi-conj-table,
	# even though they seemingly have identical function.  See
	# fi_conj_map in findeclgen.py.
    }
}
